@@ -31,6 +31,7 @@
 #include "src/core/model/actions.h"
 #include "src/core/model/model.h"
 #include "src/core/patch.h"
+#include "src/deps/mcl-utils/src/vector.hpp"
 #include "src/utils/log.h"
 #include "src/utils/ver.h"
 #include <algorithm>
@@ -39,6 +40,8 @@
 #include <cstddef>
 #include <unordered_map>
 
+namespace utils = mcl::utils;
+
 namespace giada::m
 {
 namespace
@@ -92,17 +95,6 @@ void ActionRecorder::reset()
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-bool ActionRecorder::isBoundaryEnvelopeAction(const Action& a) const
-{
-	assert(a.prev != nullptr);
-	assert(a.next != nullptr);
-	return a.prev->frame > a.frame || a.next->frame < a.frame;
-}
-#endif
-
-/* -------------------------------------------------------------------------- */
-
 void ActionRecorder::updateBpm(float ratio, int quantizerStep)
 {
 	if (ratio == 1.0f)
@@ -143,49 +135,21 @@ void ActionRecorder::updateSamplerate(int systemRate, int patchRate)
 
 /* -------------------------------------------------------------------------- */
 
-bool ActionRecorder::cloneActions(ID channelId, ID newChannelId)
+void ActionRecorder::cloneActions(ID channelId, std::size_t scene, ID newChannelId)
 {
-	bool                       cloned = false;
-	std::vector<Action>        actions;
-	std::unordered_map<ID, ID> map; // Action ID mapper, old -> new
-
-	m_model.get().actions.forEachAction([&](const Action& a)
-	{
-		if (a.channelId != channelId)
-			return;
-
-		ID newActionId = actionFactory::getNewActionId();
-
-		map.insert({a.id, newActionId});
-
-		Action clone(a);
-		clone.id        = newActionId;
-		clone.channelId = newChannelId;
-
-		actions.push_back(clone);
-		cloned = true;
-	});
-
-	/* Update nextId and prevId relationships given the new action ID. */
-
-	for (Action& a : actions)
-	{
-		if (a.prevId != 0)
-			a.prevId = map.at(a.prevId);
-		if (a.nextId != 0)
-			a.nextId = map.at(a.nextId);
-	}
-
-	m_model.get().actions.rec(actions);
-	m_model.get().tracks.getChannel(newChannelId).hasActions = true;
-	m_model.swap(model::SwapType::HARD);
-
-	return cloned;
+	copyActions(channelId, scene, scene, newChannelId);
 }
 
 /* -------------------------------------------------------------------------- */
 
-void ActionRecorder::liveRec(ID channelId, MidiEvent e, Frame globalFrame)
+void ActionRecorder::copyActionsToScene(ID channelId, std::size_t srcScene, std::size_t dstScene)
+{
+	copyActions(channelId, srcScene, dstScene, channelId);
+}
+
+/* -------------------------------------------------------------------------- */
+
+void ActionRecorder::liveRec(ID channelId, std::size_t scene, MidiEvent e, Frame globalFrame)
 {
 	assert(e.isNoteOnOff()); // Can't record any other kind of events for now
 
@@ -193,30 +157,12 @@ void ActionRecorder::liveRec(ID channelId, MidiEvent e, Frame globalFrame)
 	if (m_liveActions.size() >= m_liveActions.capacity())
 		m_liveActions.reserve(m_liveActions.size() + MAX_LIVE_RECS_CHUNK);
 
-	m_liveActions.push_back(actionFactory::makeAction(actionFactory::getNewActionId(), channelId, globalFrame, e));
+	m_liveActions.push_back(actionFactory::makeAction(actionFactory::getNewActionId(), channelId, scene, globalFrame, e));
 }
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-void ActionRecorder::recordEnvelopeAction(ID channelId, Frame frame, int value, Frame lastFrameInLoop)
-{
-	assert(value >= 0 && value <= G_MAX_VELOCITY);
-
-	/* First action ever? Add actions at boundaries. Else, find action right
-	before frame 'f' and inject a new action in there. Vertical envelope points 
-	are forbidden for now. */
-
-	if (!hasActions(channelId, MidiEvent::CHANNEL_CC))
-		recordFirstEnvelopeAction(channelId, frame, value, lastFrameInLoop);
-	else
-		recordNonFirstEnvelopeAction(channelId, frame, value);
-}
-#endif
-
-/* -------------------------------------------------------------------------- */
-
-void ActionRecorder::recordMidiAction(ID channelId, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop)
+void ActionRecorder::recordMidiAction(ID channelId, std::size_t scene, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop)
 {
 	const auto [ff1, ff2] = sanitizeFrames_(f1, f2, framesInLoop);
 
@@ -226,12 +172,12 @@ void ActionRecorder::recordMidiAction(ID channelId, int note, float velocity, Fr
 	e1.setVelocityFloat(velocity);
 	e2.setVelocityFloat(velocity);
 
-	rec(channelId, ff1, ff2, e1, e2);
+	rec(channelId, scene, ff1, ff2, e1, e2);
 }
 
 /* -------------------------------------------------------------------------- */
 
-void ActionRecorder::recordSampleAction(ID channelId, int type, Frame f1, Frame f2, Frame framesInLoop)
+void ActionRecorder::recordSampleAction(ID channelId, std::size_t scene, int type, Frame f1, Frame f2, Frame framesInLoop)
 {
 	if (isSinglePressMode(channelId))
 	{
@@ -239,12 +185,12 @@ void ActionRecorder::recordSampleAction(ID channelId, int type, Frame f1, Frame
 
 		MidiEvent e1 = MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_NOTE_ON, 0, G_MAX_VELOCITY);
 		MidiEvent e2 = MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_NOTE_OFF, 0, G_MAX_VELOCITY);
-		rec(channelId, ff1, ff2, e1, e2);
+		rec(channelId, scene, ff1, ff2, e1, e2);
 	}
 	else
 	{
 		MidiEvent e1 = MidiEvent::makeFrom3Bytes(type, 0, G_MAX_VELOCITY);
-		rec(channelId, sanitizeFrame_(f1, framesInLoop), e1);
+		rec(channelId, scene, sanitizeFrame_(f1, framesInLoop), e1);
 	}
 }
 
@@ -279,88 +225,27 @@ void ActionRecorder::deleteSampleAction(ID channelId, const Action& a)
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-void ActionRecorder::deleteEnvelopeAction(ID channelId, const Action& a)
-{
-	/* Deleting a boundary action wipes out everything. */
-	/* TODO - FIX*/
-
-	if (isBoundaryEnvelopeAction(a))
-	{
-		if (a.isVolumeEnvelope())
-		{
-			// TODO reset all channel's volume vars to 1.0
-		}
-		clearActions(channelId, a.event.getStatus());
-	}
-	else
-	{
-		assert(a.prev != nullptr);
-		assert(a.next != nullptr);
-
-		const Action a1     = *a.prev;
-		const Action a1prev = *a1.prev;
-		const Action a3     = *a.next;
-		const Action a3next = *a3.next;
-
-		/* Original status:   a1--->a--->a3
-		   Modified status:   a1-------->a3 
-		Order is important, here: first update siblings, then delete the action.
-		Otherwise ActionRecorder::deleteAction() would complain of missing 
-		prevId/nextId no longer found. */
-
-		updateSiblings(a1.id, a1prev.id, a3.id);
-		updateSiblings(a3.id, a1.id, a3next.id);
-		deleteAction(channelId, a.id);
-	}
-
-	m_model.swap(model::SwapType::SOFT);
-}
-#endif
-
-/* -------------------------------------------------------------------------- */
-
-void ActionRecorder::updateMidiAction(ID channelId, const Action& a, int note, float velocity,
+void ActionRecorder::updateMidiAction(ID channelId, std::size_t scene, const Action& a, int note, float velocity,
     Frame f1, Frame f2, Frame framesInLoop)
 {
 	deleteAction(channelId, a.id, a.nextId);
-	recordMidiAction(channelId, note, velocity, f1, f2, framesInLoop);
+	recordMidiAction(channelId, scene, note, velocity, f1, f2, framesInLoop);
 }
 
 /* -------------------------------------------------------------------------- */
 
-void ActionRecorder::updateSampleAction(ID channelId, const Action& a, int type, Frame f1, Frame f2, Frame framesInLoop)
+void ActionRecorder::updateSampleAction(ID channelId, std::size_t scene, const Action& a, int type, Frame f1, Frame f2, Frame framesInLoop)
 {
 	if (isSinglePressMode(channelId))
 		deleteAction(channelId, a.id, a.nextId);
 	else
 		deleteAction(channelId, a.id);
 
-	recordSampleAction(channelId, type, f1, f2, framesInLoop);
+	recordSampleAction(channelId, scene, type, f1, f2, framesInLoop);
 }
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-void ActionRecorder::updateEnvelopeAction(ID channelId, const Action& a, Frame f, int value, Frame lastFrameInLoop)
-{
-	/* Update the action directly if it is a boundary one. Else, delete the
-	previous one and record a new action. */
-
-	if (isBoundaryEnvelopeAction(a))
-		updateEvent(a.id, MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_CC, 0, value));
-	else
-	{
-		deleteEnvelopeAction(channelId, a);
-		recordEnvelopeAction(channelId, f, value, lastFrameInLoop);
-	}
-
-	m_model.swap(model::SwapType::SOFT);
-}
-#endif
-
-/* -------------------------------------------------------------------------- */
-
 void ActionRecorder::updateVelocity(const Action& a, float value)
 {
 	MidiEvent event(a.event);
@@ -370,12 +255,12 @@ void ActionRecorder::updateVelocity(const Action& a, float value)
 
 /* -------------------------------------------------------------------------- */
 
-std::unordered_set<ID> ActionRecorder::consolidate()
+std::unordered_set<ID> ActionRecorder::consolidate(std::size_t scene)
 {
 	for (auto it = m_liveActions.begin(); it != m_liveActions.end(); ++it)
 		consolidate(*it, it - m_liveActions.begin()); // Pass current index
 
-	m_model.get().actions.rec(m_liveActions);
+	m_model.get().actions.rec(m_liveActions, scene);
 	m_model.swap(model::SwapType::SOFT);
 
 	std::unordered_set<ID> out;
@@ -452,45 +337,43 @@ void ActionRecorder::consolidate(const Action& a1, std::size_t i)
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-void ActionRecorder::recordFirstEnvelopeAction(ID channelId, Frame frame, int value, Frame lastFrameInLoop)
+void ActionRecorder::copyActions(ID channelId, std::size_t srcScene, std::size_t dstScene, ID newChannelId)
 {
-	// TODO - use MidiEvent's float velocity
-	const MidiEvent e1 = MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_CC, 0, G_MAX_VELOCITY);
-	const MidiEvent e2 = MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_CC, 0, value);
+	const std::size_t          scene = srcScene == dstScene ? srcScene : dstScene;
+	std::vector<Action>        actions;
+	std::unordered_map<ID, ID> map; // Action ID mapper, old -> new
 
-	const Action a1 = rec(channelId, 0, e1);
-	const Action a2 = rec(channelId, frame, e2);
-	const Action a3 = rec(channelId, lastFrameInLoop, e1);
+	m_model.get().actions.forEachAction([&](const Action& a)
+	{
+		if (a.channelId != channelId)
+			return;
 
-	updateSiblings(a1.id, /*prev=*/a3.id, /*next=*/a2.id); // Circular loop (begin)
-	updateSiblings(a2.id, /*prev=*/a1.id, /*next=*/a3.id);
-	updateSiblings(a3.id, /*prev=*/a2.id, /*next=*/a1.id); // Circular loop (end)
+		ID newActionId = actionFactory::getNewActionId();
+
+		map.insert({a.id, newActionId});
+
+		Action clone(a);
+		clone.id        = newActionId;
+		clone.channelId = newChannelId;
+		clone.scene     = scene;
+
+		actions.push_back(clone);
+	});
+
+	/* Update nextId and prevId relationships given the new action ID. */
+
+	for (Action& a : actions)
+	{
+		if (a.prevId != 0)
+			a.prevId = map.at(a.prevId);
+		if (a.nextId != 0)
+			a.nextId = map.at(a.nextId);
+	}
+
+	m_model.get().actions.rec(actions, scene);
+	m_model.get().tracks.getChannel(newChannelId).hasActions = true;
+	m_model.swap(model::SwapType::HARD);
 }
-#endif
-
-/* -------------------------------------------------------------------------- */
-
-#if 0
-void ActionRecorder::recordNonFirstEnvelopeAction(ID channelId, Frame frame, int value)
-{
-	const Action a1 = m_model.get().actions.getClosestAction(channelId, frame, MidiEvent::CHANNEL_CC);
-	const Action a3 = a1.next != nullptr ? *a1.next : Action{};
-
-	assert(a1.isValid());
-	assert(a3.isValid());
-
-	frame = fixVerticalEnvActions(frame, a1, a3);
-	if (frame == -1) // Vertical points, nothing to do here
-		return;
-
-	// TODO - use MidiEvent's float velocity
-	MidiEvent    e2 = MidiEvent::makeFrom3Bytes(MidiEvent::CHANNEL_CC, 0, value);
-	const Action a2 = rec(channelId, frame, e2);
-
-	updateSiblings(a2.id, a1.id, a3.id);
-}
-#endif
 
 /* -------------------------------------------------------------------------- */
 
@@ -504,15 +387,17 @@ bool ActionRecorder::hasActions(ID channelId, int type) const
 	return m_model.get().actions.hasActions(channelId, type);
 }
 
-std::vector<Action> ActionRecorder::getActionsOnChannel(ID channelId) const
+std::vector<Action> ActionRecorder::getActionsOnChannel(ID channelId, std::size_t scene) const
 {
-	return m_model.get().actions.getActionsOnChannel(channelId);
+	return m_model.get().actions.getActionsOnChannel(channelId, scene);
 }
 
-void ActionRecorder::clearChannel(ID channelId)
+void ActionRecorder::clearChannel(ID channelId, std::size_t sceneToClear)
 {
-	m_model.get().tracks.getChannel(channelId).hasActions = false;
-	m_model.get().actions.clearChannel(channelId);
+	for (const std::size_t scene : utils::vector::range(G_MAX_NUM_SCENES))
+		if (sceneToClear == G_INVALID_SCENE || sceneToClear == scene)
+			m_model.get().actions.clearChannel(channelId, scene);
+	m_model.get().tracks.getChannel(channelId).hasActions = hasActions(channelId);
 	m_model.swap(model::SwapType::HARD);
 }
 
@@ -523,19 +408,19 @@ void ActionRecorder::clearActions(ID channelId, int type)
 	m_model.swap(model::SwapType::HARD);
 }
 
-Action ActionRecorder::rec(ID channelId, Frame frame, MidiEvent e)
+Action ActionRecorder::rec(ID channelId, std::size_t scene, Frame frame, MidiEvent e)
 {
-	Action action = m_model.get().actions.rec(channelId, frame, e);
+	Action action = m_model.get().actions.rec(channelId, scene, frame, e);
 
 	m_model.get().tracks.getChannel(channelId).hasActions = true;
 	m_model.swap(model::SwapType::HARD);
 	return action;
 }
 
-void ActionRecorder::rec(ID channelId, Frame f1, Frame f2, MidiEvent e1, MidiEvent e2)
+void ActionRecorder::rec(ID channelId, std::size_t scene, Frame f1, Frame f2, MidiEvent e1, MidiEvent e2)
 {
 	m_model.get().tracks.getChannel(channelId).hasActions = true;
-	m_model.get().actions.rec(channelId, f1, f2, e1, e2);
+	m_model.get().actions.rec(channelId, scene, f1, f2, e1, e2);
 	m_model.swap(model::SwapType::HARD);
 }
 
