@@ -41,7 +41,7 @@ struct Action;
 namespace giada::m
 {
 struct Action;
-class ActionRecorder
+class ActionRecorder // TODO - rename ActionManager
 {
 public:
 	ActionRecorder(model::Model&);
@@ -67,43 +67,39 @@ public:
 	Clones actions in channel 'channelId', giving them a new channel ID. Returns
 	whether any action has been cloned. */
 
-	bool cloneActions(ID channelId, ID newChannelId);
+	void cloneActions(ID channelId, std::size_t scene, ID newChannelId);
+
+	/* copyActionsToScene
+	Copies actions of a given channel from a scene to another. */
+
+	void copyActionsToScene(ID channelId, std::size_t srcScene, std::size_t dstScene);
 
 	/* liveRec
 	Records a user-generated action. NOTE_ON or NOTE_OFF only for now. */
 
-	void liveRec(ID channelId, MidiEvent e, Frame global);
+	void liveRec(ID channelId, std::size_t scene, MidiEvent e, Frame global);
 
 	/* record*Action */
 
-#if 0
-	void recordEnvelopeAction(ID channelId, Frame frame, int value, Frame lastFrameInLoop);
-#endif
-	void recordMidiAction(ID channelId, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop);
-	void recordSampleAction(ID channelId, int type, Frame f1, Frame f2, Frame framesInLoop);
+	void recordMidiAction(ID channelId, std::size_t scene, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop);
+	void recordSampleAction(ID channelId, std::size_t scene, int type, Frame f1, Frame f2, Frame framesInLoop);
 
 	/* delete*Action */
 
 	void deleteMidiAction(ID channelId, const Action&);
 	void deleteSampleAction(ID channelId, const Action&);
-#if 0
-	void deleteEnvelopeAction(ID channelId, const Action&);
-#endif
 
 	/* update*Action */
 
-	void updateMidiAction(ID channelId, const Action&, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop);
-	void updateSampleAction(ID channelId, const Action&, int type, Frame f1, Frame f2, Frame framesInLoop);
-#if 0
-	void updateEnvelopeAction(ID channelId, const Action&, Frame f, int value, Frame lastFrameInLoop);
-#endif
+	void updateMidiAction(ID channelId, std::size_t scene, const Action&, int note, float velocity, Frame f1, Frame f2, Frame framesInLoop);
+	void updateSampleAction(ID channelId, std::size_t scene, const Action&, int type, Frame f1, Frame f2, Frame framesInLoop);
 	void updateVelocity(const Action&, float value);
 
 	/* consolidate
 	Records all live actions. Returns a set of channels IDs that have been
 	recorded. */
 
-	std::unordered_set<ID> consolidate();
+	std::unordered_set<ID> consolidate(std::size_t scene);
 
 	/* clearAllActions
 	Deletes all recorded actions. */
@@ -114,15 +110,21 @@ public:
 
 	const Action*       findAction(ID) const;
 	bool                hasActions(ID channelId, int type = 0) const;
-	std::vector<Action> getActionsOnChannel(ID channelId) const;
-	void                clearChannel(ID channelId);
-	void                clearActions(ID channelId, int type);
-	Action              rec(ID channelId, Frame frame, MidiEvent e);
-	void                rec(ID channelId, Frame f1, Frame f2, MidiEvent e1, MidiEvent e2);
-	void                updateSiblings(ID id, ID prevId, ID nextId);
-	void                deleteAction(ID channelId, ID id);
-	void                deleteAction(ID channelId, ID currId, ID nextId);
-	void                updateEvent(ID id, MidiEvent e);
+	std::vector<Action> getActionsOnChannel(ID channelId, std::size_t scene) const;
+
+	/* clearChannel
+	Removes all actions from channel 'channelId' from a given scene. Pass G_INVALID_SCENE
+	to remove all actions from all scenes. */
+
+	void clearChannel(ID channelId, std::size_t scene);
+
+	void   clearActions(ID channelId, int type);
+	Action rec(ID channelId, std::size_t scene, Frame frame, MidiEvent e);
+	void   rec(ID channelId, std::size_t scene, Frame f1, Frame f2, MidiEvent e1, MidiEvent e2);
+	void   updateSiblings(ID id, ID prevId, ID nextId);
+	void   deleteAction(ID channelId, ID id);
+	void   deleteAction(ID channelId, ID currId, ID nextId);
+	void   updateEvent(ID id, MidiEvent e);
 
 private:
 	/* areComposite
@@ -133,26 +135,16 @@ private:
 	Frame fixVerticalEnvActions(Frame f, const Action& a1, const Action& a2) const;
 	bool  isSinglePressMode(ID channelId) const;
 
-	/* recordFirstEnvelopeAction
-	First action ever? Add actions at boundaries. */
-#if 0
-	void recordFirstEnvelopeAction(ID channelId, Frame frame, int value, Frame lastFrameInLoop);
-
-	/* recordNonFirstEnvelopeAction
-	Find action right before frame 'frame' and inject a new action in there. 
-	Vertical envelope points are forbidden. */
-
-	void recordNonFirstEnvelopeAction(ID channelId, Frame frame, int value);
-#endif
 	/* consolidate
 	Given an action 'a1' tries to find the matching NOTE_OFF and updates the
 	action accordingly. */
 
 	void consolidate(const Action& a1, std::size_t i);
 
-#if 0
-	bool isBoundaryEnvelopeAction(const Action&) const;
-#endif
+	/* cloneActions
+	Internal generic method for copying actions between channels and/or scenes. */
+
+	void copyActions(ID channelId, std::size_t srcScene, std::size_t dstScene, ID newChannelId);
 
 	model::Model&       m_model;
 	std::vector<Action> m_liveActions;
