@@ -79,8 +79,9 @@ public:
 	int      loadSampleChannel(ID channelId, const std::string& filePath);
 	void     loadSampleChannel(ID channelId, Wave&);
 	void     remove(ID);
-	void     freeSampleChannel(ID);
+	void     freeSampleChannel(ID, bool allScenes);
 	void     clone(ID);
+	void     copyToScene(ID, std::size_t dstScene);
 
 	void press(ID, float velocity);
 	void release(ID);
@@ -101,7 +102,7 @@ public:
 	void setSendToMaster(ID, bool value);
 	void addExtraOutput(ID, int);
 	void removeExtraOutput(ID, std::size_t);
-	void clearAllActions(ID);
+	void clearAllActions(ID, bool allScenes);
 	void clearAllActions();
 	void freeAllSampleChannels();
 	void sendMidi(ID, const MidiEvent&);
