@@ -63,7 +63,8 @@ bool MainApi::isRecordingActions() const
 
 bool MainApi::canRecordInput() const
 {
-	return m_kernelAudio.isInputEnabled() && m_channelManager.hasInputRecordableChannels();
+	const std::size_t scene = m_sequencer.getCurrentScene();
+	return m_kernelAudio.isInputEnabled() && m_channelManager.hasInputRecordableChannels(scene);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -188,6 +189,25 @@ SeqStatus MainApi::getSequencerStatus() const
 
 /* -------------------------------------------------------------------------- */
 
+std::size_t MainApi::getCurrentScene() const
+{
+	return m_sequencer.getCurrentScene();
+}
+
+std::size_t MainApi::getNextScene() const
+{
+	return m_sequencer.getNextScene();
+}
+
+/* -------------------------------------------------------------------------- */
+
+SceneStatus MainApi::getSceneStatus() const
+{
+	return m_sequencer.getSceneStatus();
+}
+
+/* -------------------------------------------------------------------------- */
+
 void MainApi::toggleMetronome()
 {
 	m_sequencer.toggleMetronome();
@@ -325,4 +345,12 @@ void MainApi::startActionRecOnCallback()
 {
 	m_recorder.startActionRecOnCallback();
 }
+
+/* -------------------------------------------------------------------------- */
+
+void MainApi::setScene(std::size_t scene)
+{
+	m_sequencer.setScene(scene);
+	m_reactor.setScene(scene);
+}
 } // namespace giada::m
