@@ -30,8 +30,12 @@
 #include "src/core/kernelAudio.h"
 #include "src/core/mixer.h"
 #include "src/core/plugins/pluginFactory.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
+#include "src/deps/mcl-utils/src/vector.hpp"
 #include "src/utils/fs.h"
 
+namespace utils = mcl::utils;
+
 namespace giada::m
 {
 PluginsApi::PluginsApi(KernelAudio& ka, PluginManager& pm, PluginHost& ph, model::Model& m)
@@ -104,7 +108,7 @@ void PluginsApi::sort(PluginSortMode mode)
 
 void PluginsApi::free(const Plugin& plugin, ID channelId)
 {
-	u::vector::remove(m_model.get().tracks.getChannel(channelId).plugins, &plugin);
+	utils::vector::remove(m_model.get().tracks.getChannel(channelId).plugins, &plugin);
 	m_model.swap(model::SwapType::HARD);
 	m_pluginHost.freePlugin(plugin);
 }
@@ -135,7 +139,7 @@ void PluginsApi::setParameter(ID pluginId, int paramIndex, float value)
 void PluginsApi::scan(const std::string& dir, const std::function<bool(float)>& progress)
 {
 	m_pluginManager.scanDirs(dir, progress);
-	m_pluginManager.saveList(u::fs::join(u::fs::getConfigDirPath(), "plugins.xml"));
+	m_pluginManager.saveList(utils::fs::join(u::fs::getConfigDirPath(), "plugins.xml"));
 }
 
 /* -------------------------------------------------------------------------- */
