@@ -33,9 +33,11 @@
 #include "src/core/patchFactory.h"
 #include "src/core/plugins/pluginFactory.h"
 #include "src/core/waveFactory.h"
-#include "src/utils/fs.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
 #include "src/utils/log.h"
 
+namespace utils = mcl::utils;
+
 namespace giada::m
 {
 StorageApi::StorageApi(Engine& e, model::Model& m, PluginManager& pm, MidiSynchronizer& ms,
@@ -59,7 +61,7 @@ bool StorageApi::storeProject(const std::string& projectPath, const v::Model& ui
 {
 	progress(0.0f);
 
-	if (!u::fs::mkdir(projectPath))
+	if (!utils::fs::mkdir(projectPath))
 	{
 		u::log::print("[StorageApi::storeProject] Unable to make project directory!\n");
 		return false;
@@ -79,7 +81,7 @@ bool StorageApi::storeProject(const std::string& projectPath, const v::Model& ui
 
 	progress(0.6f);
 
-	const std::string patchPath = u::fs::join(projectPath, patch.name + G_PATCH_EXT);
+	const std::string patchPath = utils::fs::join(projectPath, patch.name + G_PATCH_EXT);
 
 	if (!patchFactory::serialize(patch, patchPath))
 		return false;
@@ -101,7 +103,7 @@ model::LoadState StorageApi::loadProject(const std::string& projectPath, std::fu
 
 	/* Read the selected project's patch. */
 
-	const std::string patchPath = u::fs::join(projectPath, u::fs::stripExt(u::fs::basename(projectPath)) + G_PATCH_EXT);
+	const std::string patchPath = utils::fs::join(projectPath, utils::fs::stripExt(utils::fs::basename(projectPath)) + G_PATCH_EXT);
 	const Patch       patch     = patchFactory::deserialize(patchPath);
 
 	if (patch.status != G_FILE_OK)
