@@ -104,10 +104,11 @@ Data create(const Channel& o, int bufferSize, Resampler::Quality quality)
 
 /* -------------------------------------------------------------------------- */
 
-Channel deserializeChannel(const Patch::Channel& pch, ChannelShared& shared, float samplerateRatio, Wave* wave, std::vector<Plugin*> plugins)
+Channel deserializeChannel(const Patch::Channel& pch, ChannelShared& shared, float samplerateRatio,
+    const SceneArray<Sample>& samples, std::vector<Plugin*> plugins)
 {
 	channelId_.set(pch.id);
-	return Channel(pch, shared, samplerateRatio, wave, plugins);
+	return Channel(pch, shared, samplerateRatio, samples, plugins);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -129,7 +130,6 @@ const Patch::Channel serializeChannel(const Channel& c)
 	pc.id                = c.id;
 	pc.type              = c.type;
 	pc.height            = c.height;
-	pc.name              = c.name;
 	pc.key               = c.key;
 	pc.mute              = c.isMuted();
 	pc.solo              = c.isSoloed();
@@ -155,14 +155,13 @@ const Patch::Channel serializeChannel(const Channel& c)
 	pc.midiOutLplaying   = c.midiLightning.playing.getValue();
 	pc.midiOutLmute      = c.midiLightning.mute.getValue();
 	pc.midiOutLsolo      = c.midiLightning.solo.getValue();
+	pc.names             = c.getNames();
 
 	if (c.type == ChannelType::SAMPLE)
 	{
-		pc.waveId            = c.sampleChannel->getWaveId();
+		for (std::size_t i = 0; i < G_MAX_NUM_SCENES; i++)
+			pc.samples[i] = {c.sampleChannel->getWaveId(i), c.sampleChannel->getRange(i), c.sampleChannel->getShift(i), c.sampleChannel->getPitch(i)}; // TODO - scenes - use std::transform
 		pc.mode              = c.sampleChannel->mode;
-		pc.range             = c.sampleChannel->range;
-		pc.pitch             = c.sampleChannel->pitch;
-		pc.shift             = c.sampleChannel->shift;
 		pc.midiInVeloAsVol   = c.sampleChannel->velocityAsVol;
 		pc.inputMonitor      = c.sampleChannel->inputMonitor;
 		pc.overdubProtection = c.sampleChannel->overdubProtection;
