@@ -62,7 +62,7 @@ class ChannelManager final
 public:
 	friend Engine;
 
-	ChannelManager(model::Model&, MidiMapper<KernelMidi>&, ActionRecorder&, KernelMidi&);
+	ChannelManager(model::Model&, MidiMapper<KernelMidi>&, KernelMidi&);
 
 	/* getChannel
 	Returns channel object by ID. */
@@ -72,7 +72,7 @@ public:
 	/* hasInputRecordableChannels
 	Tells whether Mixer has one or more input-recordable channels. */
 
-	bool hasInputRecordableChannels() const;
+	bool hasInputRecordableChannels(std::size_t scene) const;
 
 	/* hasActions
 	True if at least one Channel has actions recorded in it. */
@@ -130,33 +130,40 @@ public:
 	/* loadSampleChannel (1)
 	Creates a new Wave from a file path and loads it inside a Sample Channel. */
 
-	int loadSampleChannel(ID channelId, const std::string&, int sampleRate, Resampler::Quality);
+	int loadSampleChannel(ID channelId, const std::string&, int sampleRate, Resampler::Quality, std::size_t scene);
 
 	/* loadSampleChannel (2)
 	Loads an existing Wave inside a Sample Channel. */
 
-	void loadSampleChannel(ID channelId, Wave&);
+	void loadSampleChannel(ID channelId, Wave&, std::size_t scene);
 
 	/* freeChannel
-	Unloads existing Wave from a Sample Channel. */
+	Unloads existing Wave from a Sample Channel. Pass G_INVALID_SCENE as 'scene' parameter
+	to remove all Waves from all scenes. */
 
-	void freeSampleChannel(ID channelId);
-	void freeAllSampleChannels();
+	void freeSampleChannel(ID channelId, std::size_t scene);
+
+	void freeAllSampleChannels(std::size_t scene);
 
 	void moveChannel(ID, std::size_t newTrackIndex, std::size_t newPosition);
 	void deleteChannel(ID channelId);
-	void renameChannel(ID channelId, const std::string& name);
+	void renameChannel(ID channelId, const std::string& name, std::size_t scene);
 
 	/* cloneChannel
 	Creates a duplicate of Channel. Wants a vector of already cloned plug-ins. */
 
-	void cloneChannel(ID channelId, int bufferSize, const std::vector<Plugin*>&);
+	void cloneChannel(ID channelId, std::size_t scene, int bufferSize, const std::vector<Plugin*>&);
+
+	/* copyChannelToScene
+	Copies channel's data between scenes. */
+
+	void copyChannelToScene(ID channelId, std::size_t srcScene, std::size_t dstScene);
 
 	/* finalizeInputRec
 	Fills armed Sample channel with audio data coming from an input recording
 	session. */
 
-	void finalizeInputRec(const mcl::AudioBuffer&, Frame recordedFrames, Frame currentFrame);
+	void finalizeInputRec(const mcl::AudioBuffer&, Frame recordedFrames, Frame currentFrame, std::size_t scene);
 
 	/* finalizeActionRec
 	Enable reading actions for Channels that have just been filled with actions
@@ -168,10 +175,10 @@ public:
 
 	void setInputMonitor(ID channelId, bool value);
 	void setVolume(ID channelId, float value);
-	void setPitch(ID channelId, float value);
+	void setPitch(ID channelId, float value, std::size_t scene);
 	void setPan(ID channelId, float value);
-	void setRange(ID channelId, SampleRange);
-	void resetRange(ID channelId);
+	void setRange(ID channelId, SampleRange, std::size_t scene);
+	void resetRange(ID channelId, std::size_t scene);
 	void toggleArm(ID channelId);
 	void setOverdubProtection(ID channelId, bool value);
 	void setSamplePlayerMode(ID channelId, SamplePlayerMode);
@@ -179,7 +186,7 @@ public:
 	void setSendToMaster(ID channelId, bool value);
 	void addExtraOutput(ID channelId, int offset);
 	void removeExtraOutput(ID channelId, std::size_t);
-	void loadWaveInPreviewChannel(ID sourceChannelId);
+	void loadWaveInPreviewChannel(ID sourceChannelId, std::size_t scene);
 	void freeWaveInPreviewChannel();
 	void setPreviewTracker(Frame f);
 	bool saveSample(ID channelId, const std::string& filePath);
@@ -202,7 +209,7 @@ public:
 	std::function<void(ID, ChannelStatus)> onChannelPlayStatusChanged;
 
 private:
-	void loadSampleChannel(Channel&, Wave*) const;
+	void loadSampleChannel(Channel&, Wave*, std::size_t scene) const;
 
 	/* setupChannelCallbacks
 	Prepares the channel with the necessary callbacks. Call this whenever a
@@ -210,8 +217,8 @@ private:
 
 	void setupChannelCallbacks(const Channel&, ChannelShared&) const;
 
-	std::vector<Channel*> getRecordableChannels();
-	std::vector<Channel*> getOverdubbableChannels();
+	std::vector<Channel*> getRecordableChannels(std::size_t scene);
+	std::vector<Channel*> getOverdubbableChannels(std::size_t scene);
 
 	/* setupChannelPostRecording
 	Fnialize the Sample channel after an audio recording session. */
@@ -221,19 +228,18 @@ private:
 	/* recordChannel
 	Records the current Mixer audio input data into an empty channel. */
 
-	void recordChannel(Channel&, const mcl::AudioBuffer&, Frame recordedFrames, Frame currentFrame);
+	void recordChannel(Channel&, const mcl::AudioBuffer&, Frame recordedFrames, Frame currentFrame, std::size_t scene);
 
 	/* overdubChannel
 	Records the current Mixer audio input data into a channel with an existing
 	Wave, overdub mode. */
 
-	void overdubChannel(Channel&, const mcl::AudioBuffer&, Frame currentFrame);
+	void overdubChannel(Channel&, const mcl::AudioBuffer&, Frame currentFrame, std::size_t scene);
 
 	void triggerOnChannelsAltered();
 
 	model::Model&           m_model;
 	KernelMidi&             m_kernelMidi;
-	ActionRecorder&         m_actionRecorder;
 	MidiMapper<KernelMidi>& m_midiMapper;
 };
 } // namespace giada::m
