@@ -27,12 +27,12 @@
 #ifndef G_MIXER_H
 #define G_MIXER_H
 
-#include "core/midiEvent.h"
-#include "core/ringBuffer.h"
-#include "core/sequencer.h"
-#include "core/types.h"
-#include "core/weakAtomic.h"
-#include "deps/mcl-audio-buffer/src/audioBuffer.hpp"
+#include "src/core/midiEvent.h"
+#include "src/core/ringBuffer.h"
+#include "src/core/sequencer.h"
+#include "src/core/types.h"
+#include "src/core/weakAtomic.h"
+#include "src/deps/mcl-audio-buffer/src/audioBuffer.hpp"
 #include <functional>
 
 namespace mcl
@@ -54,10 +54,6 @@ class Channel;
 class Mixer
 {
 public:
-	static constexpr int MASTER_OUT_CHANNEL_ID = 1;
-	static constexpr int MASTER_IN_CHANNEL_ID  = 2;
-	static constexpr int PREVIEW_CHANNEL_ID    = 3;
-
 	/* RecordInfo
 	Information regarding the input recording progress. */
 
@@ -139,11 +135,16 @@ public:
 
 	/* finalizeOutput
 	Last touches after the output has been rendered: apply inToOut if any, apply
-	output volume, compute peak. */
+	output volume. */
 
 	void finalizeOutput(const model::Mixer&, mcl::AudioBuffer&, bool inToOut,
 	    bool limit, float vol) const;
 
+	/* updateOutputPeak
+	Reads the maximum peak in the given buffer and updates the value in model::Mixer. */
+
+	void updateOutputPeak(const model::Mixer&, const mcl::AudioBuffer&) const;
+
 	void setRecTriggerMode(RecTriggerMode);
 	void setInputRecMode(InputRecMode);
 
