@@ -26,13 +26,15 @@
 
 #include "src/core/model/channels.h"
 #include "src/core/plugins/plugin.h"
-#include "src/utils/vector.h"
+#include "src/deps/mcl-utils/src/vector.hpp"
 #include <cassert>
 #if G_DEBUG_MODE
 #include "src/utils/string.h"
 #include <fmt/core.h>
 #endif
 
+namespace utils = mcl::utils;
+
 namespace giada::m::model
 {
 Channel* Channels::find(ID id)
@@ -85,7 +87,7 @@ const std::vector<Channel>& Channels::getAll() const
 
 const std::size_t Channels::getIndex(ID id) const
 {
-	return static_cast<std::size_t>(u::vector::indexOf(m_channels, get(id)));
+	return static_cast<std::size_t>(utils::vector::indexOf(m_channels, get(id)));
 }
 
 /* -------------------------------------------------------------------------- */
@@ -143,7 +145,7 @@ std::vector<Channel*> Channels::getIf(std::function<bool(const Channel&)> f)
 
 void Channels::remove(ID id)
 {
-	u::vector::removeIf(m_channels, [id](const Channel& c)
+	utils::vector::removeIf(m_channels, [id](const Channel& c)
 	{ return c.id == id; });
 }
 
