@@ -88,6 +88,25 @@ float Sequencer::a_getCurrentSecond(int sampleRate) const
 
 /* -------------------------------------------------------------------------- */
 
+std::size_t Sequencer::a_getCurrentScene() const
+{
+	return shared->currentScene.load();
+}
+
+std::size_t Sequencer::a_getNextScene() const
+{
+	return shared->nextScene.load();
+}
+
+/* -------------------------------------------------------------------------- */
+
+SceneStatus Sequencer::a_getSceneStatus() const
+{
+	return shared->sceneStatus.load();
+}
+
+/* -------------------------------------------------------------------------- */
+
 int Sequencer::getMaxFramesInLoop(int sampleRate) const
 {
 	return (sampleRate * (60.0f / G_MIN_BPM)) * beats;
@@ -108,4 +127,23 @@ void Sequencer::a_setCurrentBeat(int b, int sampleRate) const
 	shared->currentFrame.store(currentFrame);
 	shared->currentBeat.store(b);
 }
+
+/* -------------------------------------------------------------------------- */
+
+void Sequencer::a_setCurrentScene(std::size_t scene) const
+{
+	shared->currentScene.store(scene);
+}
+
+void Sequencer::a_setNextScene(std::size_t scene) const
+{
+	shared->nextScene.store(scene);
+}
+
+/* -------------------------------------------------------------------------- */
+
+void Sequencer::a_setSceneStatus(SceneStatus s) const
+{
+	shared->sceneStatus.store(s);
+}
 } // namespace giada::m::model
