@@ -60,9 +60,12 @@ public:
 	bool a_isOnBeat() const;
 	bool a_isOnFirstBeat() const;
 
-	Frame a_getCurrentFrame() const;
-	Frame a_getCurrentBeat() const;
-	float a_getCurrentSecond(int sampleRate) const;
+	Frame       a_getCurrentFrame() const;
+	Frame       a_getCurrentBeat() const;
+	float       a_getCurrentSecond(int sampleRate) const;
+	std::size_t a_getCurrentScene() const;
+	std::size_t a_getNextScene() const;
+	SceneStatus a_getSceneStatus() const;
 
 	/* getMaxFramesInLoop
 	Returns how many frames the current loop length might contain at the slowest
@@ -72,6 +75,9 @@ public:
 
 	void a_setCurrentFrame(Frame f, int sampleRate) const;
 	void a_setCurrentBeat(int b, int sampleRate) const;
+	void a_setCurrentScene(std::size_t) const;
+	void a_setNextScene(std::size_t) const;
+	void a_setSceneStatus(SceneStatus) const;
 
 	SeqStatus status       = SeqStatus::STOPPED;
 	int       framesInLoop = 0;
@@ -87,8 +93,16 @@ public:
 private:
 	struct Shared
 	{
-		WeakAtomic<Frame> currentFrame = 0;
-		WeakAtomic<int>   currentBeat  = 0;
+		WeakAtomic<Frame>       currentFrame = 0;
+		WeakAtomic<int>         currentBeat  = 0;
+		WeakAtomic<std::size_t> currentScene = 0;
+		WeakAtomic<std::size_t> nextScene    = 0;
+
+		/* m_sceneStatus
+		IDLE = current scene selected. CHANGING = a change of scene has been requested
+		and will go back to IDLE at the next first beat. */
+
+		WeakAtomic<SceneStatus> sceneStatus = SceneStatus::IDLE;
 	};
 
 	Shared* shared = nullptr;
