@@ -29,12 +29,14 @@
 #include "src/core/plugins/pluginFactory.h"
 #include "src/core/plugins/pluginManager.h"
 #include "src/core/waveFactory.h"
-#include "src/utils/vector.h"
+#include "src/deps/mcl-utils/src/vector.hpp"
 #if G_DEBUG_MODE
 #include <fmt/core.h>
 #endif
 #include <fmt/ostream.h>
 
+namespace utils = mcl::utils;
+
 namespace giada::m::model
 {
 namespace
@@ -42,7 +44,7 @@ namespace
 template <typename T>
 auto getIter_(const std::vector<std::unique_ptr<T>>& source, ID id)
 {
-	return u::vector::findIf(source, [id](const std::unique_ptr<T>& p)
+	return utils::vector::findIf(source, [id](const std::unique_ptr<T>& p)
 	{ return p->id == id; });
 }
 
@@ -55,6 +57,16 @@ auto* get_(S& source, ID id)
 	return it == source.end() ? nullptr : it->get();
 }
 
+template <typename S>
+auto get_(S& source, std::vector<ID> ids)
+{
+	using RawPtr = decltype(source.front().get());
+	std::vector<RawPtr> out;
+	for (const ID id : ids)
+		out.push_back(get_(source, id));
+	return out;
+}
+
 /* -------------------------------------------------------------------------- */
 
 template <typename T>
@@ -69,7 +81,7 @@ typename T::element_type& add_(std::vector<T>& dest, T obj)
 template <typename D, typename T>
 void remove_(D& dest, T& ref)
 {
-	u::vector::removeIf(dest, [&ref](const auto& other)
+	utils::vector::removeIf(dest, [&ref](const auto& other)
 	{ return other.get() == &ref; });
 }
 } // namespace
@@ -174,9 +186,10 @@ std::vector<std::unique_ptr<ChannelShared>>& Shared::getAllChannels() { return m
 
 /* -------------------------------------------------------------------------- */
 
-Plugin*        Shared::findPlugin(ID id) { return get_(m_plugins, id); }
-Wave*          Shared::findWave(ID id) { return get_(m_waves, id); }
-ChannelShared* Shared::findChannel(ID id) { return get_(m_channels, id); }
+Plugin*            Shared::findPlugin(ID id) { return get_(m_plugins, id); }
+Wave*              Shared::findWave(ID id) { return get_(m_waves, id); }
+std::vector<Wave*> Shared::findWaves(std::vector<ID> ids) { return get_(m_waves, ids); }
+ChannelShared*     Shared::findChannel(ID id) { return get_(m_channels, id); }
 
 /* -------------------------------------------------------------------------- */
 
