@@ -24,29 +24,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "core/patch.h"
+#include "src/core/patch.h"
 
-namespace giada::m
+namespace geompp
 {
-bool Patch::Version::operator==(const Version& o) const
+void to_json(nlohmann::json& j, const giada::SampleRange& r)
 {
-	return major == o.major && minor == o.minor && patch == o.patch;
+	j = nlohmann::json{{"a", r.a}, {"b", r.b}};
 }
 
-bool Patch::Version::operator<(const Version& o) const
+void from_json(const nlohmann::json& j, giada::SampleRange& r)
 {
-	if (major < o.major)
-		return true;
-	else if (o.major < major)
-		return false;
-	if (minor < o.minor)
-		return true;
-	else if (o.minor < minor)
-		return false;
-	if (patch < o.patch)
-		return true;
-	else if (o.patch < patch)
-		return false;
-	return false;
+	r.a = j.value("a", 0);
+	r.b = j.value("b", 0);
 }
-} // namespace giada::m
+} // namespace geompp
\ No newline at end of file
