@@ -27,12 +27,14 @@
 #include "src/core/patchFactory.h"
 #include "src/core/const.h"
 #include "src/core/mixer.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
 #include "src/gui/const.h"
-#include "src/utils/fs.h"
 #include "src/utils/log.h"
 #include <fstream>
 #include <nlohmann/json.hpp>
 
+namespace utils = mcl::utils;
+
 namespace giada::m::patchFactory
 {
 namespace
@@ -54,7 +56,7 @@ constexpr auto PATCH_KEY_CHANNELS                     = "channels";
 constexpr auto PATCH_KEY_CHANNEL_TYPE                 = "type";
 constexpr auto PATCH_KEY_CHANNEL_ID                   = "id";
 constexpr auto PATCH_KEY_CHANNEL_SIZE                 = "size";
-constexpr auto PATCH_KEY_CHANNEL_NAME                 = "name";
+constexpr auto PATCH_KEY_CHANNEL_NAMES                = "names";
 constexpr auto PATCH_KEY_CHANNEL_MUTE                 = "mute";
 constexpr auto PATCH_KEY_CHANNEL_SOLO                 = "solo";
 constexpr auto PATCH_KEY_CHANNEL_VOLUME               = "volume";
@@ -75,15 +77,11 @@ constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L           = "midi_out_l";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_PLAYING   = "midi_out_l_playing";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_MUTE      = "midi_out_l_mute";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_SOLO      = "midi_out_l_solo";
-constexpr auto PATCH_KEY_CHANNEL_WAVE_ID              = "wave_id";
 constexpr auto PATCH_KEY_CHANNEL_KEY                  = "key";
+constexpr auto PATCH_KEY_CHANNEL_SAMPLES              = "samples";
 constexpr auto PATCH_KEY_CHANNEL_MODE                 = "mode";
-constexpr auto PATCH_KEY_CHANNEL_BEGIN                = "begin";
-constexpr auto PATCH_KEY_CHANNEL_END                  = "end";
-constexpr auto PATCH_KEY_CHANNEL_SHIFT                = "shift";
 constexpr auto PATCH_KEY_CHANNEL_HAS_ACTIONS          = "has_actions";
 constexpr auto PATCH_KEY_CHANNEL_READ_ACTIONS         = "read_actions";
-constexpr auto PATCH_KEY_CHANNEL_PITCH                = "pitch";
 constexpr auto PATCH_KEY_CHANNEL_INPUT_MONITOR        = "input_monitor";
 constexpr auto PATCH_KEY_CHANNEL_OVERDUB_PROTECTION   = "overdub_protection";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_IN_READ_ACTIONS = "midi_in_read_actions";
@@ -107,6 +105,7 @@ constexpr auto PATCH_KEY_TRACK_INTERNAL               = "internal";
 constexpr auto PATCH_KEY_TRACK_CHANNELS               = "channels";
 constexpr auto G_PATCH_KEY_ACTION_ID                  = "id";
 constexpr auto G_PATCH_KEY_ACTION_CHANNEL             = "channel";
+constexpr auto G_PATCH_KEY_ACTION_SCENE               = "scene";
 constexpr auto G_PATCH_KEY_ACTION_FRAME               = "frame";
 constexpr auto G_PATCH_KEY_ACTION_EVENT               = "event";
 constexpr auto G_PATCH_KEY_ACTION_PREV                = "prev";
@@ -183,7 +182,7 @@ void readWaves_(Patch& patch, const nlohmann::json& j, const std::string& basePa
 	{
 		Patch::Wave w;
 		w.id   = jwave.value(PATCH_KEY_WAVE_ID, ++id);
-		w.path = u::fs::join(basePath, jwave.value(PATCH_KEY_WAVE_PATH, ""));
+		w.path = utils::fs::join(basePath, jwave.value(PATCH_KEY_WAVE_PATH, ""));
 		patch.waves.push_back(w);
 	}
 }
@@ -201,6 +200,7 @@ void readActions_(Patch& patch, const nlohmann::json& j)
 		Patch::Action a;
 		a.id        = jaction.value(G_PATCH_KEY_ACTION_ID, ++id);
 		a.channelId = jaction.value(G_PATCH_KEY_ACTION_CHANNEL, 0);
+		a.scene     = jaction.value(G_PATCH_KEY_ACTION_SCENE, 0);
 		a.frame     = jaction.value(G_PATCH_KEY_ACTION_FRAME, 0);
 		a.event     = jaction.value(G_PATCH_KEY_ACTION_EVENT, 0);
 		a.prevId    = jaction.value(G_PATCH_KEY_ACTION_PREV, 0);
@@ -225,7 +225,6 @@ void readChannels_(Patch& patch, const nlohmann::json& j)
 		c.type              = static_cast<ChannelType>(jchannel.value(PATCH_KEY_CHANNEL_TYPE, 1));
 		c.volume            = jchannel.value(PATCH_KEY_CHANNEL_VOLUME, G_DEFAULT_VOL);
 		c.height            = jchannel.value(PATCH_KEY_CHANNEL_SIZE, G_GUI_UNIT);
-		c.name              = jchannel.value(PATCH_KEY_CHANNEL_NAME, "");
 		c.key               = jchannel.value(PATCH_KEY_CHANNEL_KEY, 0);
 		c.mute              = jchannel.value(PATCH_KEY_CHANNEL_MUTE, 0);
 		c.solo              = jchannel.value(PATCH_KEY_CHANNEL_SOLO, 0);
@@ -247,12 +246,7 @@ void readChannels_(Patch& patch, const nlohmann::json& j)
 		c.midiOutLsolo      = jchannel.value(PATCH_KEY_CHANNEL_MIDI_OUT_L_SOLO, 0);
 		c.armed             = jchannel.value(PATCH_KEY_CHANNEL_ARMED, false);
 		c.mode              = static_cast<SamplePlayerMode>(jchannel.value(PATCH_KEY_CHANNEL_MODE, 1));
-		c.waveId            = jchannel.value(PATCH_KEY_CHANNEL_WAVE_ID, 0);
-		c.range.a           = jchannel.value(PATCH_KEY_CHANNEL_BEGIN, 0);
-		c.range.b           = jchannel.value(PATCH_KEY_CHANNEL_END, 0);
-		c.shift             = jchannel.value(PATCH_KEY_CHANNEL_SHIFT, 0);
 		c.readActions       = jchannel.value(PATCH_KEY_CHANNEL_READ_ACTIONS, false);
-		c.pitch             = jchannel.value(PATCH_KEY_CHANNEL_PITCH, G_DEFAULT_PITCH);
 		c.inputMonitor      = jchannel.value(PATCH_KEY_CHANNEL_INPUT_MONITOR, false);
 		c.overdubProtection = jchannel.value(PATCH_KEY_CHANNEL_OVERDUB_PROTECTION, false);
 		c.midiInVeloAsVol   = jchannel.value(PATCH_KEY_CHANNEL_MIDI_IN_VELO_AS_VOL, 0);
@@ -261,6 +255,12 @@ void readChannels_(Patch& patch, const nlohmann::json& j)
 		c.midiOut           = jchannel.value(PATCH_KEY_CHANNEL_MIDI_OUT, 0);
 		c.midiOutChan       = jchannel.value(PATCH_KEY_CHANNEL_MIDI_OUT_CHAN, 0);
 
+		if (jchannel.contains(PATCH_KEY_CHANNEL_NAMES))
+			c.names = jchannel[PATCH_KEY_CHANNEL_NAMES];
+
+		if (jchannel.contains(PATCH_KEY_CHANNEL_SAMPLES))
+			c.samples = jchannel[PATCH_KEY_CHANNEL_SAMPLES];
+
 		if (jchannel.contains(PATCH_KEY_CHANNEL_PLUGINS))
 			for (const auto& jplugin : jchannel[PATCH_KEY_CHANNEL_PLUGINS])
 				c.pluginIds.push_back(jplugin);
@@ -326,6 +326,7 @@ void writeActions_(const Patch& patch, nlohmann::json& j)
 		nlohmann::json jaction;
 		jaction[G_PATCH_KEY_ACTION_ID]      = a.id;
 		jaction[G_PATCH_KEY_ACTION_CHANNEL] = a.channelId;
+		jaction[G_PATCH_KEY_ACTION_SCENE]   = a.scene;
 		jaction[G_PATCH_KEY_ACTION_FRAME]   = a.frame;
 		jaction[G_PATCH_KEY_ACTION_EVENT]   = a.event;
 		jaction[G_PATCH_KEY_ACTION_PREV]    = a.prevId;
@@ -380,7 +381,6 @@ void writeChannels_(const Patch& patch, nlohmann::json& j)
 		jchannel[PATCH_KEY_CHANNEL_ID]                   = c.id;
 		jchannel[PATCH_KEY_CHANNEL_TYPE]                 = static_cast<int>(c.type);
 		jchannel[PATCH_KEY_CHANNEL_SIZE]                 = c.height;
-		jchannel[PATCH_KEY_CHANNEL_NAME]                 = c.name;
 		jchannel[PATCH_KEY_CHANNEL_MUTE]                 = c.mute;
 		jchannel[PATCH_KEY_CHANNEL_SOLO]                 = c.solo;
 		jchannel[PATCH_KEY_CHANNEL_VOLUME]               = c.volume;
@@ -402,13 +402,8 @@ void writeChannels_(const Patch& patch, nlohmann::json& j)
 		jchannel[PATCH_KEY_CHANNEL_MIDI_OUT_L_MUTE]      = c.midiOutLmute;
 		jchannel[PATCH_KEY_CHANNEL_MIDI_OUT_L_SOLO]      = c.midiOutLsolo;
 		jchannel[PATCH_KEY_CHANNEL_KEY]                  = c.key;
-		jchannel[PATCH_KEY_CHANNEL_WAVE_ID]              = c.waveId;
 		jchannel[PATCH_KEY_CHANNEL_MODE]                 = static_cast<int>(c.mode);
-		jchannel[PATCH_KEY_CHANNEL_BEGIN]                = c.range.a;
-		jchannel[PATCH_KEY_CHANNEL_END]                  = c.range.b;
-		jchannel[PATCH_KEY_CHANNEL_SHIFT]                = c.shift;
 		jchannel[PATCH_KEY_CHANNEL_READ_ACTIONS]         = c.readActions;
-		jchannel[PATCH_KEY_CHANNEL_PITCH]                = c.pitch;
 		jchannel[PATCH_KEY_CHANNEL_INPUT_MONITOR]        = c.inputMonitor;
 		jchannel[PATCH_KEY_CHANNEL_OVERDUB_PROTECTION]   = c.overdubProtection;
 		jchannel[PATCH_KEY_CHANNEL_MIDI_IN_VELO_AS_VOL]  = c.midiInVeloAsVol;
@@ -417,6 +412,14 @@ void writeChannels_(const Patch& patch, nlohmann::json& j)
 		jchannel[PATCH_KEY_CHANNEL_MIDI_OUT]             = c.midiOut;
 		jchannel[PATCH_KEY_CHANNEL_MIDI_OUT_CHAN]        = c.midiOutChan;
 
+		jchannel[PATCH_KEY_CHANNEL_NAMES] = nlohmann::json::array();
+		for (const std::string& name : c.names)
+			jchannel[PATCH_KEY_CHANNEL_NAMES].push_back(name);
+
+		jchannel[PATCH_KEY_CHANNEL_SAMPLES] = nlohmann::json::array();
+		for (const Patch::Sample& sample : c.samples)
+			jchannel[PATCH_KEY_CHANNEL_SAMPLES].push_back(sample);
+
 		jchannel[PATCH_KEY_CHANNEL_PLUGINS] = nlohmann::json::array();
 		for (ID pid : c.pluginIds)
 			jchannel[PATCH_KEY_CHANNEL_PLUGINS].push_back(pid);
@@ -431,7 +434,7 @@ void writeChannels_(const Patch& patch, nlohmann::json& j)
 
 /* -------------------------------------------------------------------------- */
 
-void modernize_(Patch& patch)
+void modernize_(Patch& patch, nlohmann::json& j)
 {
 	/* 1.1.0
 	Older patches don't contain Tracks. Let's recreate a basic Track layout: one
@@ -454,6 +457,28 @@ void modernize_(Patch& patch)
 			}
 		}
 	}
+
+	/* 1.4.0
+	Older patches don't support scenes. This is a problem for sample channels. Let's
+	put all samples and their properties into scene 0. */
+	if (patch.version < Version{1, 4, 0})
+	{
+		for (Patch::Channel& c : patch.channels)
+		{
+			if (c.type != ChannelType::SAMPLE)
+				continue;
+			for (const auto& jchannel : j[PATCH_KEY_CHANNELS])
+			{
+				if (jchannel.value(PATCH_KEY_CHANNEL_ID, 0) != c.id)
+					continue;
+				c.names[0]          = jchannel.value("name", "");
+				c.samples[0].waveId = jchannel.value("wave_id", 0);
+				c.samples[0].range  = {jchannel.value("begin", 0), jchannel.value("end", 0)};
+				c.samples[0].shift  = jchannel.value("shift", 0);
+				c.samples[0].pitch  = jchannel.value("pitch", 0.0f);
+			}
+		}
+	}
 }
 
 /* -------------------------------------------------------------------------- */
@@ -473,10 +498,6 @@ void sanitize_(Patch& patch)
 		const bool isInternalChannel = c.type == ChannelType::PREVIEW || c.type == ChannelType::MASTER;
 		if (isInternalChannel)
 			c.armed = false;
-
-		/* Set waveId to 0 for non-Sample Channels. */
-		if (c.type != ChannelType::SAMPLE)
-			c.waveId = 0;
 	}
 }
 } // namespace
@@ -540,10 +561,10 @@ Patch deserialize(const std::string& filePath)
 		readCommons_(patch, j);
 		readTracks_(patch, j);
 		readPlugins_(patch, j);
-		readWaves_(patch, j, u::fs::dirname(filePath));
+		readWaves_(patch, j, utils::fs::dirname(filePath));
 		readActions_(patch, j);
 		readChannels_(patch, j);
-		modernize_(patch);
+		modernize_(patch, j);
 		sanitize_(patch);
 	}
 	catch (nlohmann::json::exception& e)
