@@ -50,16 +50,17 @@ class Reactor
 public:
 	Reactor(model::Model&, MidiMapper<KernelMidi>&, ActionRecorder&, KernelMidi&);
 
-	void keyPress(ID channelId, float velocity, bool canRecordActions, bool canQuantize, Frame currentFrameQuantized);
-	void keyRelease(ID channelId, bool canRecordActions, Frame currentFrameQuantized);
-	void keyKill(ID channelId, bool canRecordActions, Frame currentFrameQuantized);
-	void processMidiEvent(ID channelId, const MidiEvent&, bool canRecordActions, Frame currentFrameQuantized);
+	void keyPress(ID channelId, std::size_t scene, float velocity, bool canRecordActions, bool canQuantize, Frame currentFrameQuantized);
+	void keyRelease(ID channelId, std::size_t scene, bool canRecordActions, Frame currentFrameQuantized);
+	void keyKill(ID channelId, std::size_t scene, bool canRecordActions, Frame currentFrameQuantized);
+	void processMidiEvent(ID channelId, std::size_t scene, const MidiEvent&, bool canRecordActions, Frame currentFrameQuantized);
 	void toggleReadActions(ID channelId, bool seqIsRunning);
 	void killReadActions(ID channelId);
 	void toggleMute(ID channelId);
 	void toggleSolo(ID channelId);
 	void stopAll();
 	void rewindAll();
+	void setScene(std::size_t);
 
 private:
 	model::Model&           m_model;
