@@ -114,12 +114,12 @@ void onNoteOn_(ChannelShared& shared, Frame localFrame, SamplePlayerMode mode, f
 
 /* -------------------------------------------------------------------------- */
 
-void parseActions_(ID channelId, ChannelShared& shared, const std::vector<Action>& as,
+void parseActions_(ID channelId, std::size_t scene, ChannelShared& shared, const std::vector<Action>& as,
     Frame localFrame, SamplePlayerMode mode)
 {
 	for (const Action& a : as)
 	{
-		if (a.channelId != channelId)
+		if (a.channelId != channelId || a.scene != scene)
 			continue;
 
 		switch (a.event.getStatus())
@@ -167,7 +167,7 @@ void advanceSampleChannel(const Channel& ch, const Sequencer::Event& e)
 
 	case Sequencer::EventType::ACTIONS:
 		if (!isLoop && ch.shared->isReadingActions())
-			parseActions_(ch.id, *ch.shared, *e.actions, e.delta, mode);
+			parseActions_(ch.id, e.scene, *ch.shared, *e.actions, e.delta, mode);
 		break;
 
 	default:
