@@ -26,7 +26,6 @@
 
 #include "src/core/rendering/sampleReactions.h"
 #include "src/core/actions/actionRecorder.h"
-#include "src/utils/math.h"
 
 namespace giada::m::rendering
 {
@@ -37,9 +36,9 @@ constexpr int Q_ACTION_REWIND = 10000; // Avoid clash with Q_ACTION_PLAY + chann
 
 /* -------------------------------------------------------------------------- */
 
-void record_(ID channelId, int note, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
+void record_(ID channelId, std::size_t scene, int note, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
 {
-	actionRecorder.liveRec(channelId, MidiEvent::makeFrom3Bytes(note, 0, 0), currentFrameQuantized);
+	actionRecorder.liveRec(channelId, scene, MidiEvent::makeFrom3Bytes(note, 0, 0), currentFrameQuantized);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -129,9 +128,9 @@ ChannelStatus pressWhilePlay_(ID channelId, ChannelShared& shared, SamplePlayerM
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void recordSampleKeyPress(ID channelId, ChannelShared& shared, Frame currentFrameQuantized, SamplePlayerMode mode, ActionRecorder& actionRecorder)
+void recordSampleKeyPress(ID channelId, std::size_t scene, ChannelShared& shared, Frame currentFrameQuantized, SamplePlayerMode mode, ActionRecorder& actionRecorder)
 {
-	record_(channelId, MidiEvent::CHANNEL_NOTE_ON, currentFrameQuantized, actionRecorder);
+	record_(channelId, scene, MidiEvent::CHANNEL_NOTE_ON, currentFrameQuantized, actionRecorder);
 
 	/* Skip reading actions when recording on ChannelMode::SINGLE_PRESS to
 	prevent	existing actions to interfere with the keypress/keyrel combo. */
@@ -142,16 +141,16 @@ void recordSampleKeyPress(ID channelId, ChannelShared& shared, Frame currentFram
 
 /* -------------------------------------------------------------------------- */
 
-void recordSampleKeyRelease(ID channelId, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
+void recordSampleKeyRelease(ID channelId, std::size_t scene, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
 {
-	record_(channelId, MidiEvent::CHANNEL_NOTE_OFF, currentFrameQuantized, actionRecorder);
+	record_(channelId, scene, MidiEvent::CHANNEL_NOTE_OFF, currentFrameQuantized, actionRecorder);
 }
 
 /* -------------------------------------------------------------------------- */
 
-void recordSampleKeyKill(ID channelId, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
+void recordSampleKeyKill(ID channelId, std::size_t scene, Frame currentFrameQuantized, ActionRecorder& actionRecorder)
 {
-	record_(channelId, MidiEvent::CHANNEL_NOTE_KILL, currentFrameQuantized, actionRecorder);
+	record_(channelId, scene, MidiEvent::CHANNEL_NOTE_KILL, currentFrameQuantized, actionRecorder);
 }
 
 /* -------------------------------------------------------------------------- */
