@@ -32,8 +32,8 @@
 #include "src/core/midiSynchronizer.h"
 #include "src/core/model/model.h"
 #include "src/core/quantizer.h"
+#include "src/deps/mcl-utils/src/math.hpp"
 #include "src/utils/log.h"
-#include "src/utils/math.h"
 #include "src/utils/time.h"
 
 namespace giada::m
@@ -50,6 +50,7 @@ constexpr int Q_ACTION_REWIND = 0;
 Sequencer::Sequencer(model::Model& m, MidiSynchronizer& s, JackTransport& j)
 : onAboutStart(nullptr)
 , onAboutStop(nullptr)
+, onSceneChanged(nullptr)
 , m_model(m)
 , m_midiSynchronizer(s)
 , m_jackTransport(j)
@@ -60,27 +61,30 @@ Sequencer::Sequencer(model::Model& m, MidiSynchronizer& s, JackTransport& j)
 }
 /* -------------------------------------------------------------------------- */
 
-bool      Sequencer::canQuantize() const { return m_model.get().sequencer.canQuantize(); }
-bool      Sequencer::isRunning() const { return m_model.get().sequencer.isRunning(); }
-bool      Sequencer::isActive() const { return m_model.get().sequencer.isActive(); }
-bool      Sequencer::isOnBar() const { return m_model.get().sequencer.a_isOnBar(); }
-bool      Sequencer::isOnBeat() const { return m_model.get().sequencer.a_isOnBeat(); }
-bool      Sequencer::isOnFirstBeat() const { return m_model.get().sequencer.a_isOnFirstBeat(); }
-float     Sequencer::getBpm() const { return m_model.get().sequencer.bpm; }
-int       Sequencer::getBeats() const { return m_model.get().sequencer.beats; }
-int       Sequencer::getBars() const { return m_model.get().sequencer.bars; }
-int       Sequencer::getCurrentBeat() const { return m_model.get().sequencer.a_getCurrentBeat(); }
-Frame     Sequencer::getCurrentFrame() const { return m_model.get().sequencer.a_getCurrentFrame(); }
-Frame     Sequencer::getCurrentFrameQuantized() const { return quantize(getCurrentFrame()); }
-float     Sequencer::getCurrentSecond(int sampleRate) const { return getCurrentFrame() / static_cast<float>(sampleRate); }
-Frame     Sequencer::getFramesInBar() const { return m_model.get().sequencer.framesInBar; }
-Frame     Sequencer::getFramesInBeat() const { return m_model.get().sequencer.framesInBeat; }
-Frame     Sequencer::getFramesInLoop() const { return m_model.get().sequencer.framesInLoop; }
-Frame     Sequencer::getFramesInSeq() const { return m_model.get().sequencer.framesInSeq; }
-int       Sequencer::getQuantizerValue() const { return m_model.get().sequencer.quantize; }
-int       Sequencer::getQuantizerStep() const { return m_quantizerStep; }
-SeqStatus Sequencer::getStatus() const { return m_model.get().sequencer.status; }
-int       Sequencer::getMaxFramesInLoop(int sampleRate) const { return m_model.get().sequencer.getMaxFramesInLoop(sampleRate); }
+bool        Sequencer::canQuantize() const { return m_model.get().sequencer.canQuantize(); }
+bool        Sequencer::isRunning() const { return m_model.get().sequencer.isRunning(); }
+bool        Sequencer::isActive() const { return m_model.get().sequencer.isActive(); }
+bool        Sequencer::isOnBar() const { return m_model.get().sequencer.a_isOnBar(); }
+bool        Sequencer::isOnBeat() const { return m_model.get().sequencer.a_isOnBeat(); }
+bool        Sequencer::isOnFirstBeat() const { return m_model.get().sequencer.a_isOnFirstBeat(); }
+float       Sequencer::getBpm() const { return m_model.get().sequencer.bpm; }
+int         Sequencer::getBeats() const { return m_model.get().sequencer.beats; }
+int         Sequencer::getBars() const { return m_model.get().sequencer.bars; }
+int         Sequencer::getCurrentBeat() const { return m_model.get().sequencer.a_getCurrentBeat(); }
+Frame       Sequencer::getCurrentFrame() const { return m_model.get().sequencer.a_getCurrentFrame(); }
+Frame       Sequencer::getCurrentFrameQuantized() const { return quantize(getCurrentFrame()); }
+float       Sequencer::getCurrentSecond(int sampleRate) const { return getCurrentFrame() / static_cast<float>(sampleRate); }
+Frame       Sequencer::getFramesInBar() const { return m_model.get().sequencer.framesInBar; }
+Frame       Sequencer::getFramesInBeat() const { return m_model.get().sequencer.framesInBeat; }
+Frame       Sequencer::getFramesInLoop() const { return m_model.get().sequencer.framesInLoop; }
+Frame       Sequencer::getFramesInSeq() const { return m_model.get().sequencer.framesInSeq; }
+int         Sequencer::getQuantizerValue() const { return m_model.get().sequencer.quantize; }
+int         Sequencer::getQuantizerStep() const { return m_quantizerStep; }
+SeqStatus   Sequencer::getStatus() const { return m_model.get().sequencer.status; }
+int         Sequencer::getMaxFramesInLoop(int sampleRate) const { return m_model.get().sequencer.getMaxFramesInLoop(sampleRate); }
+std::size_t Sequencer::getCurrentScene() const { return m_model.get().sequencer.a_getCurrentScene(); }
+std::size_t Sequencer::getNextScene() const { return m_model.get().sequencer.a_getNextScene(); }
+SceneStatus Sequencer::getSceneStatus() const { return m_model.get().sequencer.a_getSceneStatus(); }
 
 /* -------------------------------------------------------------------------- */
 
@@ -93,9 +97,11 @@ float Sequencer::calcBpmFromRec(Frame recordedFrames, int sampleRate) const
 
 Frame Sequencer::quantize(Frame f) const
 {
+	namespace math = mcl::utils::math;
+
 	if (!canQuantize())
 		return f;
-	return u::math::quantize(f, m_quantizerStep) % getFramesInLoop(); // No overflow
+	return math::quantize(f, m_quantizerStep) % getFramesInLoop(); // No overflow
 }
 
 /* -------------------------------------------------------------------------- */
@@ -133,17 +139,28 @@ const Sequencer::EventBuffer& Sequencer::advance(const model::Sequencer& sequenc
 	const Frame framesInBeat = sequencer.framesInBeat;
 	const Frame nextFrame    = end % framesInLoop;
 
+	const std::size_t currentScene = sequencer.a_getCurrentScene();
+	const std::size_t nextScene    = sequencer.a_getNextScene();
+	bool              sceneChanged = false;
+
 	/* Process events in the current block. */
 
 	for (Frame i = start, local = 0; i < end; i++, local++)
 	{
-
 		Frame global = i % framesInLoop; // wraps around 'framesInLoop'
 
 		if (global == 0)
 		{
 			m_eventBuffer.push_back({EventType::FIRST_BEAT, global, local});
 			m_metronome.trigger(Metronome::Click::BEAT, local);
+			if (currentScene != nextScene)
+			{
+				assert(onSceneChanged != nullptr);
+				sequencer.a_setCurrentScene(nextScene);
+				sequencer.a_setSceneStatus(SceneStatus::IDLE);
+				sceneChanged = true;
+				onSceneChanged(); // Can't directly swap model here, this is real-time stuff
+			}
 		}
 		else if (global % framesInBar == 0)
 		{
@@ -155,9 +172,13 @@ const Sequencer::EventBuffer& Sequencer::advance(const model::Sequencer& sequenc
 			m_metronome.trigger(Metronome::Click::BEAT, local);
 		}
 
+		/* Fetch actions in the current frame. Extra care is needed if the scene
+		has changed in this block: we need to process actions that belong to the
+		next scene, not the current one (which is the old one). */
+
 		const std::vector<Action>* as = actions.getActionsOnFrame(global);
 		if (as != nullptr)
-			m_eventBuffer.push_back({EventType::ACTIONS, global, local, as});
+			m_eventBuffer.push_back({EventType::ACTIONS, global, local, as, sceneChanged ? nextScene : currentScene});
 	}
 
 	/* Advance this and quantizer after the event parsing. */
@@ -379,6 +400,31 @@ void Sequencer::goToBeat(int beat, int sampleRate)
 
 /* -------------------------------------------------------------------------- */
 
+void Sequencer::forceScene(std::size_t scene)
+{
+	assert(scene < G_MAX_NUM_SCENES);
+
+	m_model.get().sequencer.a_setCurrentScene(scene);
+}
+
+/* -------------------------------------------------------------------------- */
+
+void Sequencer::setScene(std::size_t scene)
+{
+	assert(scene < G_MAX_NUM_SCENES);
+
+	if (scene == m_model.get().sequencer.a_getCurrentScene())
+		return;
+	if (!isRunning())
+		m_model.get().sequencer.a_setCurrentScene(scene);
+	else
+		m_model.get().sequencer.a_setSceneStatus(SceneStatus::CHANGING);
+	m_model.get().sequencer.a_setNextScene(scene);
+	m_model.swap(model::SwapType::HARD);
+}
+
+/* -------------------------------------------------------------------------- */
+
 #ifdef WITH_AUDIO_JACK
 
 void Sequencer::jack_start()
