@@ -31,7 +31,7 @@
 #include "src/core/wave.h"
 #include "src/core/waveFx.h"
 #include "src/deps/mcl-audio-buffer/src/audioBuffer.hpp"
-#include "src/utils/fs.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
 #include "src/utils/log.h"
 #include <cmath>
 #include <fmt/core.h>
@@ -39,6 +39,8 @@
 #include <samplerate.h>
 #include <sndfile.h>
 
+namespace utils = mcl::utils;
+
 namespace giada::m::waveFactory
 {
 namespace
@@ -70,7 +72,7 @@ int getBits_(const SF_INFO& header)
 
 std::string makeWavePath_(const std::string& base, const m::Wave& w, int k)
 {
-	return u::fs::join(base, fmt::format("{}-{}{}", w.getBasename(/*ext=*/false), k, w.getExtension()));
+	return utils::fs::join(base, fmt::format("{}-{}{}", w.getBasename(/*ext=*/false), k, w.getExtension()));
 }
 
 /* -------------------------------------------------------------------------- */
@@ -92,7 +94,7 @@ bool isWavePathUnique_(const m::Wave& skip, const std::string& path,
 std::string makeUniqueWavePath(const std::string& base, const m::Wave& w,
     const std::vector<std::unique_ptr<Wave>>& waves)
 {
-	std::string path = u::fs::join(base, w.getBasename(/*ext=*/true));
+	std::string path = utils::fs::join(base, w.getBasename(/*ext=*/true));
 	if (isWavePathUnique_(w, path, waves))
 		return path;
 
@@ -118,7 +120,7 @@ void reset()
 
 Result createFromFile(const std::string& path, ID id, int samplerate, Resampler::Quality quality)
 {
-	if (path == "" || u::fs::isDir(path))
+	if (path == "" || utils::fs::isDir(path))
 	{
 		u::log::print("[waveFactory::create] malformed path (was '{}')\n", path);
 		return {G_RES_ERR_NO_DATA};
@@ -212,7 +214,7 @@ std::unique_ptr<Wave> deserializeWave(const Patch::Wave& w, int samplerate, Resa
 
 const Patch::Wave serializeWave(const Wave& w)
 {
-	return {w.id, u::fs::basename(w.getPath())};
+	return {w.id, utils::fs::basename(w.getPath())};
 }
 
 /* -------------------------------------------------------------------------- */
