@@ -24,11 +24,11 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "waveFx.h"
-#include "const.h"
-#include "deps/mcl-audio-buffer/src/audioBuffer.hpp"
-#include "utils/log.h"
-#include "wave.h"
+#include "src/core/waveFx.h"
+#include "src/core/const.h"
+#include "src/core/wave.h"
+#include "src/deps/mcl-audio-buffer/src/audioBuffer.hpp"
+#include "src/utils/log.h"
 #include <algorithm>
 #include <cassert>
 #include <cmath>
@@ -189,9 +189,9 @@ void paste(const Wave& src, Wave& des, Frame a)
 	/* |---original data---|///paste data///|---original data---|
 	         des[0, a)      src[0, src.size)   des[a, des.size)	*/
 
-	newData.set(desBuffer, /*framesToCopy=*/a, /*srcOffset=*/0);
-	newData.set(srcBuffer, /*framesToCopy=*/srcBuffer.countFrames(), /*srcOffset=*/0, /*dstOffset=*/a);
-	newData.set(desBuffer, /*framesToCopy=*/-1, /*srcOffset=*/a, /*dstOffset=*/srcBuffer.countFrames() + a);
+	newData.setAll(desBuffer, /*framesToCopy=*/a, /*srcOffset=*/0, /*dstOffset=*/0);
+	newData.setAll(srcBuffer, /*framesToCopy=*/srcBuffer.countFrames(), /*srcOffset=*/0, /*dstOffset=*/a);
+	newData.setAll(desBuffer, /*framesToCopy=*/-1, /*srcOffset=*/a, /*dstOffset=*/srcBuffer.countFrames() + a);
 
 	des.replaceData(std::move(newData));
 	des.setEdited(true);
