@@ -44,9 +44,10 @@ SampleData::SampleData(const m::SampleChannel& s)
 
 /* -------------------------------------------------------------------------- */
 
-Data::Data(const m::Channel& c)
+Data::Data(const m::Channel& c, std::size_t scene)
 : channelId(c.id)
-, channelName(c.name)
+, scene(scene)
+, channelName(c.getName(scene))
 , framesInSeq(g_engine->getMainApi().getFramesInSeq())
 , framesInBeat(g_engine->getMainApi().getFramesInBeat())
 , framesInBar(g_engine->getMainApi().getFramesInBar())
@@ -77,7 +78,7 @@ bool Data::isChannelPlaying() const
 
 Data getData(ID channelId)
 {
-	return Data(g_engine->getChannelsApi().get(channelId));
+	return Data(g_engine->getChannelsApi().get(channelId), g_engine->getMainApi().getCurrentScene());
 }
 
 /* -------------------------------------------------------------------------- */
@@ -132,31 +133,6 @@ void deleteSampleAction(ID channelId, const m::Action& a)
 
 /* -------------------------------------------------------------------------- */
 
-#if 0
-
-void recordEnvelopeAction(ID channelId, Frame f, int value)
-{
-	g_engine->getActionEditorApi().recordEnvelopeAction(channelId, f, value);
-}
-
-/* -------------------------------------------------------------------------- */
-
-void deleteEnvelopeAction(ID channelId, const m::Action& a)
-{
-	g_engine->getActionEditorApi().deleteEnvelopeAction(channelId, a);
-}
-
-/* -------------------------------------------------------------------------- */
-
-void updateEnvelopeAction(ID channelId, const m::Action& a, Frame f, int value)
-{
-	g_engine->getActionEditorApi().updateEnvelopeAction(channelId, a, f, value);
-}
-
-#endif
-
-/* -------------------------------------------------------------------------- */
-
 void updateVelocity(const m::Action& a, float value)
 {
 	g_engine->getActionEditorApi().updateVelocity(a, value);
