@@ -55,12 +55,13 @@ struct SampleData
 struct Data
 {
 	Data() = default;
-	Data(const m::Channel&);
+	Data(const m::Channel&, std::size_t scene);
 
 	Frame getCurrentFrame() const;
 	bool  isChannelPlaying() const;
 
 	ID                     channelId;
+	std::size_t            scene;
 	std::string            channelName;
 	Frame                  framesInSeq;
 	Frame                  framesInBeat;
@@ -90,14 +91,6 @@ void recordSampleAction(ID channelId, int type, Frame f1, Frame f2 = 0);
 void deleteSampleAction(ID channelId, const m::Action& a);
 void updateSampleAction(ID channelId, const m::Action& a, int type,
     Frame f1, Frame f2 = 0);
-
-/* Envelope actions (only volume for now). */
-
-#if 0
-void recordEnvelopeAction(ID channelId, Frame f, int value);
-void deleteEnvelopeAction(ID channelId, const m::Action& a);
-void updateEnvelopeAction(ID channelId, const m::Action& a, Frame f, int value);
-#endif
 } // namespace giada::c::actionEditor
 
 #endif
