@@ -58,7 +58,7 @@ namespace giada::c::channel
 struct SampleData
 {
 	SampleData() = delete;
-	SampleData(const m::Channel&);
+	SampleData(const m::Channel&, std::size_t scene);
 
 	Frame getTracker() const;
 
@@ -85,7 +85,7 @@ struct MidiData
 
 struct Data
 {
-	Data(const m::Channel&, std::size_t trackIndex, std::size_t channelIndex);
+	Data(const m::Channel&, std::size_t scene, std::size_t trackIndex, std::size_t channelIndex);
 
 	ChannelStatus getPlayStatus() const;
 	ChannelStatus getRecStatus() const;
@@ -95,6 +95,7 @@ struct Data
 	bool          isMuted() const;
 	bool          isSoloed() const;
 	bool          isArmed() const;
+	bool          isActive() const;
 
 	ID                      id;
 	std::size_t             trackIndex;
@@ -177,13 +178,18 @@ void deleteChannel(ID channelId);
 /* freeChannel
 Unloads the sample from a sample channel. */
 
-void freeChannel(ID channelId);
+void freeChannel(ID channelId, bool allScenes);
 
 /* cloneChannel
 Makes an exact copy of a channel. */
 
 void cloneChannel(ID channelId);
 
+/* copyChannelToScene
+Copies channel's content (Wave, actions, ...) from the current scene to dstScene. */
+
+void copyChannelToScene(ID channelId, std::size_t dstScene);
+
 /* moveChannel
 Moves channel with channelId to track at 'trackIndex' at 'position'. */
 
@@ -221,9 +227,10 @@ void addExtraOutput(ID channelId, int);
 void removeExtraOutput(ID channelId, int);
 
 /* clearAllActions
-Deletes all recorded actions on channel 'channelId'. */
+Deletes all recorded actions on channel 'channelId'. Pass false as 'allScenes' to
+delete only actions in the current scene. */
 
-void clearAllActions(ID channelId);
+void clearAllActions(ID channelId, bool allScenes);
 
 void setSamplePlayerMode(ID channelId, SamplePlayerMode m);
 
