@@ -171,6 +171,17 @@ MainMenu getMainMenu()
 
 /* -------------------------------------------------------------------------- */
 
+Scenes getScenes()
+{
+	const auto& mainApi = g_engine->getMainApi();
+	return {
+	    mainApi.getCurrentScene(),
+	    mainApi.getNextScene(),
+	    mainApi.getSceneStatus()};
+}
+
+/* -------------------------------------------------------------------------- */
+
 void setBeats(int beats, int bars)
 {
 	g_engine->getMainApi().setBeats(beats, bars);
@@ -284,6 +295,10 @@ void toggleInputRecording() { g_engine->getMainApi().toggleInputRecording(); }
 
 /* -------------------------------------------------------------------------- */
 
+void setScene(std::size_t scene) { g_engine->getMainApi().setScene(scene); }
+
+/* -------------------------------------------------------------------------- */
+
 #if G_DEBUG_MODE
 
 void printDebugInfo()
