@@ -39,6 +39,7 @@
 #include "src/core/sequencer.h"
 #include "src/core/wave.h"
 #include "src/core/waveFactory.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
 #include "src/glue/layout.h"
 #include "src/glue/main.h"
 #include "src/gui/dialogs/browser/browserLoad.h"
@@ -49,7 +50,6 @@
 #include "src/gui/elems/mainWindow/keyboard/keyboard.h"
 #include "src/gui/elems/mainWindow/keyboard/track.h"
 #include "src/gui/ui.h"
-#include "src/utils/fs.h"
 #include "src/utils/gui.h"
 #include "src/utils/log.h"
 #include "src/utils/string.h"
@@ -58,6 +58,8 @@
 extern giada::m::Engine* g_engine;
 extern giada::v::Ui*     g_ui;
 
+namespace utils = mcl::utils;
+
 namespace giada::c::storage
 {
 namespace
@@ -81,7 +83,7 @@ bool validateFileName_(const std::string& name)
 		v::gdAlert(g_ui->getI18Text(v::LangMap::MESSAGE_STORAGE_CHOOSEFILENAME));
 		return false;
 	}
-	if (!u::fs::isValidFileName(name))
+	if (!utils::fs::isValidFileName(name))
 	{
 		v::gdAlert(g_ui->getI18Text(v::LangMap::MESSAGE_STORAGE_FILEHASINVALIDCHARS));
 		return false;
@@ -125,7 +127,7 @@ void loadProject(void* data)
 		return;
 	}
 
-	g_ui->model.patchPath = u::fs::getUpDir(projectPath);
+	g_ui->model.patchPath = utils::fs::getUpDir(projectPath);
 	g_ui->load(state.patch);
 	g_ui->startUpdater();
 
@@ -139,13 +141,13 @@ void saveProject(void* data)
 {
 	v::gdBrowserSave* browser = static_cast<v::gdBrowserSave*>(data);
 
-	const std::string projectName = u::fs::stripExt(browser->getName());
-	const std::string projectPath = u::fs::join(browser->getCurrentPath(), projectName + G_PROJECT_EXT);
+	const std::string projectName = utils::fs::stripExt(browser->getName());
+	const std::string projectPath = utils::fs::join(browser->getCurrentPath(), projectName + G_PROJECT_EXT);
 
 	if (!validateFileName_(projectName))
 		return;
 
-	if (u::fs::dirExists(projectPath) &&
+	if (utils::fs::dirExists(projectPath) &&
 	    !v::gdConfirmWin(g_ui->getI18Text(v::LangMap::COMMON_WARNING),
 	        g_ui->getI18Text(v::LangMap::MESSAGE_STORAGE_PROJECTEXISTS)))
 		return;
@@ -159,7 +161,7 @@ void saveProject(void* data)
 	if (g_engine->getStorageApi().storeProject(projectPath, g_ui->model, engineProgress))
 	{
 		g_ui->setMainWindowTitle(projectName);
-		g_ui->model.patchPath = u::fs::getUpDir(projectPath);
+		g_ui->model.patchPath = utils::fs::getUpDir(projectPath);
 		browser->do_callback();
 	}
 	else
@@ -176,7 +178,7 @@ void loadSample(void* data)
 	if (fullPath.empty())
 		return;
 
-	g_ui->model.samplePath = u::fs::dirname(fullPath);
+	g_ui->model.samplePath = utils::fs::dirname(fullPath);
 
 	c::channel::loadChannel(browser->getChannelId(), fullPath);
 
@@ -195,9 +197,9 @@ void saveSample(void* data)
 	if (!validateFileName_(name))
 		return;
 
-	const std::string filePath = u::fs::join(folderPath, u::fs::stripExt(name) + ".wav");
+	const std::string filePath = utils::fs::join(folderPath, utils::fs::stripExt(name) + ".wav");
 
-	if (u::fs::fileExists(filePath) &&
+	if (utils::fs::fileExists(filePath) &&
 	    !v::gdConfirmWin(g_ui->getI18Text(v::LangMap::COMMON_WARNING),
 	        g_ui->getI18Text(v::LangMap::MESSAGE_STORAGE_FILEEXISTS)))
 		return;
@@ -206,7 +208,7 @@ void saveSample(void* data)
 		v::gdAlert(g_ui->getI18Text(v::LangMap::MESSAGE_STORAGE_SAVINGFILEERROR));
 	else
 	{
-		g_ui->model.samplePath = u::fs::dirname(filePath);
+		g_ui->model.samplePath = utils::fs::dirname(filePath);
 	}
 
 	browser->do_callback();
