@@ -42,6 +42,7 @@
 #include <FL/Fl.H>
 #include <FL/fl_draw.H>
 #include <cassert>
+#include <fmt/core.h>
 #include <limits>
 #include <string>
 
@@ -133,6 +134,14 @@ void gdBaseActionEditor::prepareWindow()
 
 /* -------------------------------------------------------------------------- */
 
+void gdBaseActionEditor::updateTitleWithScene(std::size_t scene)
+{
+	setTitle(fmt::format("{} - {} {}", g_ui->getI18Text(LangMap::ACTIONEDITOR_TITLE),
+	    g_ui->getI18Text(LangMap::COMMON_SCENE), scene + 1));
+}
+
+/* -------------------------------------------------------------------------- */
+
 int gdBaseActionEditor::handle(int e)
 {
 	switch (e)
