@@ -35,6 +35,7 @@
 #include "src/gui/elems/mainWindow/mainOutput.h"
 #include "src/gui/elems/mainWindow/mainTimer.h"
 #include "src/gui/elems/mainWindow/mainTransport.h"
+#include "src/gui/elems/mainWindow/scenes.h"
 #include "src/gui/elems/mainWindow/sequencer.h"
 #include "src/gui/ui.h"
 #include "src/utils/gui.h"
@@ -119,12 +120,14 @@ gdMainWindow::gdMainWindow(geompp::Rect<int> r, const char* title)
 
 			/* zone 3 - sequencer */
 
-			geFlex* zone3 = new geFlex(Direction::HORIZONTAL, G_GUI_INNER_MARGIN, {0, 15});
+			geFlex* zone3 = new geFlex(Direction::HORIZONTAL, G_GUI_INNER_MARGIN, {0, 13});
 			{
 				sequencer = new v::geSequencer();
-				zone3->addWidget(new geBox(), 80);
+				scenes    = new geScenes();
+				zone3->addWidget(new geBox(), 120);
 				zone3->addWidget(sequencer);
-				zone3->addWidget(new geBox(), 80);
+				zone3->addWidget(new geBox(), 16);
+				zone3->addWidget(scenes, 92);
 				zone3->end();
 			}
 
@@ -179,6 +182,7 @@ void gdMainWindow::refresh()
 	keyboard->refresh();
 	mainInput->refresh();
 	mainOutput->refresh();
+	scenes->refresh();
 }
 
 /* -------------------------------------------------------------------------- */
@@ -200,9 +204,9 @@ void gdMainWindow::clearKeyboard()
 
 /* -------------------------------------------------------------------------- */
 
-void gdMainWindow::setTitle(const std::string& title)
+void gdMainWindow::setMainTitle(const std::string& title)
 {
-	copy_label(fmt::format("{} - {}", G_APP_NAME, title).c_str());
+	setTitle(fmt::format("{} - {}", G_APP_NAME, title));
 }
 
 /* -------------------------------------------------------------------------- */
