@@ -40,6 +40,7 @@ class geMainMenu;
 class geSequencer;
 class geMainTransport;
 class geMainTimer;
+class geScenes;
 class gdMainWindow : public gdWindow
 {
 	class ScopedProgress;
@@ -55,10 +56,10 @@ public:
 
 	void clearKeyboard();
 
-	/* setTitle
+	/* setMainTitle
 	Sets a new window title, prefixed by "Giada - [title]". */
 
-	void setTitle(const std::string&);
+	void setMainTitle(const std::string&);
 
 	[[nodiscard]] ScopedProgress getScopedProgress(const char* msg, std::function<void()> onCancel = nullptr);
 
@@ -69,6 +70,7 @@ public:
 	geMainTransport* mainTransport;
 	geMainInput*     mainInput;
 	geMainOutput*    mainOutput;
+	geScenes*        scenes;
 
 private:
 	class ScopedProgress
