@@ -179,7 +179,7 @@ gdSampleEditor::gdSampleEditor(ID channelId, const Model& model)
 
 	rewind->onClick = [this]()
 	{
-		c::sampleEditor::setPreviewTracker(m_data.range.a);
+		c::sampleEditor::setPreviewTracker(m_data.sample.range.a);
 	};
 
 	loop->onChange = [](bool shouldLoop)
@@ -217,6 +217,15 @@ void gdSampleEditor::rebuild()
 	shiftTool->rebuild(m_data);
 
 	updateInfo();
+	updateTitleWithScene(m_data.scene);
+
+	if (!m_data.isValid())
+	{
+		rangeTool->deactivate();
+		pitchTool->deactivate();
+		shiftTool->deactivate();
+		reload->deactivate();
+	}
 
 	if (m_data.isLogical) // Logical samples (aka takes) cannot be reloaded.
 		reload->deactivate();
@@ -240,4 +249,12 @@ void gdSampleEditor::updateInfo()
 
 	info->copy_label(infoText.c_str());
 }
+
+/* -------------------------------------------------------------------------- */
+
+void gdSampleEditor::updateTitleWithScene(std::size_t scene)
+{
+	setTitle(fmt::format("{} - {} {}", g_ui->getI18Text(LangMap::ACTIONEDITOR_TITLE),
+	    g_ui->getI18Text(LangMap::COMMON_SCENE), scene + 1));
+}
 } // namespace giada::v
