@@ -73,6 +73,11 @@ public:
 private:
 	void updateInfo();
 
+	/* updateTitleWithScene
+	Updates window title with the current scene being edited. */
+
+	void updateTitleWithScene(std::size_t scene);
+
 	ID                    m_channelId;
 	c::sampleEditor::Data m_data;
 };
