@@ -38,6 +38,8 @@ namespace giada::v
 class gdWindow : public Fl_Double_Window
 {
 public:
+	void copy_label(const char*) = delete; // Use setTitle()
+
 	gdWindow(int x, int y, int w, int h, const char* title = nullptr, ID id = 0);
 	gdWindow(geompp::Rect<int>, const char* title = nullptr, ID id = 0);
 	~gdWindow();
@@ -76,6 +78,7 @@ public:
 	gdWindow* getChild(ID);
 
 	void setBounds(geompp::Rect<int>);
+	void setTitle(const std::string&);
 
 private:
 	static void cb_closeChild(Fl_Widget* /*w*/, void* p);
