@@ -28,7 +28,6 @@
 #define GE_MENU_H
 
 #include "src/types.h"
-#include <FL/Fl_Menu_.H>
 #include <FL/Fl_Menu_Button.H>
 #include <functional>
 #include <string>
@@ -41,6 +40,8 @@ public:
 	geMenu();
 
 	void addItem(ID, const char* text, int flags = 0);
+	void addItem(ID, const std::string& text, int flags = 0);
+	void addSubMenu(const std::string& text, geMenu&);
 	void setEnabled(ID, bool);
 
 	std::function<void(ID)> onSelect;
@@ -48,6 +49,11 @@ public:
 private:
 	static void callback(Fl_Widget*, void*);
 	void        callback(ID);
+
+	/* findItemById
+	Finds menu item by ID recusively (in sub-menus). Returns nullptr if not found. */
+
+	const Fl_Menu_Item* findItemById(ID targetId) const;
 };
 } // namespace giada::v
 
