@@ -32,12 +32,14 @@
 namespace giada::v
 {
 geTextButton::geTextButton(int x, int y, int w, int h, const char* l)
-: geButton(x, y, w, h, l)
+: geButton(x, y, w, h, nullptr)
 , m_backgroundColorOff(G_COLOR_GREY_2)
 , m_backgroundColorOn(G_COLOR_GREY_4)
 , m_borderColor(G_COLOR_GREY_4)
 , m_textColor(G_COLOR_LIGHT_2)
+, m_padding(16)
 {
+	copy_label(l);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -59,6 +61,13 @@ void geTextButton::draw()
 	drawRect(bounds, m_borderColor); // draw border
 
 	if (label() != nullptr)
-		drawText(u::gui::truncate(label(), w() - 16), bounds.reduced(1), FL_HELVETICA, G_GUI_FONT_SIZE_BASE, textColor);
+		drawText(u::gui::truncate(label(), w() - m_padding), bounds.reduced(1), FL_HELVETICA, G_GUI_FONT_SIZE_BASE, textColor);
+}
+
+/* -------------------------------------------------------------------------- */
+
+void geTextButton::setPadding(int p)
+{
+	m_padding = p;
 }
 } // namespace giada::v
\ No newline at end of file
