@@ -25,9 +25,11 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/gui/elems/fileBrowser.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
 #include "src/gui/const.h"
 #include "src/gui/elems/basics/boxtypes.h"
-#include "src/utils/fs.h"
+
+namespace utils = mcl::utils;
 
 namespace giada::v
 {
@@ -109,7 +111,7 @@ int geFileBrowser::handle(int e)
 		else if (Fl::event_key(FL_Enter))
 			chooseItem();
 		else if (Fl::event_key(FL_BackSpace))
-			loadDir(u::fs::getUpDir(getCurrentDir()));
+			loadDir(utils::fs::getUpDir(getCurrentDir()));
 		selectItem();
 		return 1;
 	}
@@ -139,7 +141,7 @@ int geFileBrowser::handle(int e)
 
 std::string geFileBrowser::getCurrentDir() const
 {
-	return u::fs::getRealPath(m_currentDir);
+	return utils::fs::getRealPath(m_currentDir);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -148,7 +150,7 @@ std::string geFileBrowser::getSelectedItem() const
 {
 	if (value() == 0) // no rows selected? return current directory
 		return m_currentDir;
-	return u::fs::getRealPath(u::fs::join(m_currentDir, text(value())));
+	return utils::fs::getRealPath(utils::fs::join(m_currentDir, text(value())));
 }
 
 /* -------------------------------------------------------------------------- */
@@ -164,7 +166,7 @@ void geFileBrowser::preselect(int pos, int line)
 void geFileBrowser::chooseItem()
 {
 	const std::string selectedItemPath = getSelectedItem();
-	if (u::fs::isDir(selectedItemPath))
+	if (utils::fs::isDir(selectedItemPath))
 		loadDir(selectedItemPath);
 	else if (onChooseItem != nullptr)
 		onChooseItem();
