@@ -25,18 +25,14 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/glue/channel.h"
-#include "src/glue/layout.h"
-#include "src/glue/main.h"
 #include "src/gui/const.h"
 #include "src/gui/elems/basics/dial.h"
 #include "src/gui/elems/basics/imageButton.h"
 #include "src/gui/elems/mainWindow/keyboard/channel.h"
 #include "src/gui/elems/mainWindow/keyboard/channelButton.h"
-#include "src/gui/elems/mainWindow/keyboard/channelProgress.h"
 #include "src/gui/elems/mainWindow/keyboard/track.h"
 #include "src/gui/elems/midiActivity.h"
 #include "src/gui/ui.h"
-#include <FL/Fl.H>
 #include <FL/fl_draw.H>
 
 extern giada::v::Ui* g_ui;
@@ -82,7 +78,7 @@ void geChannel::refresh()
 		mainButton->refresh();
 
 	if (recStatus == ChannelStatus::WAIT || playStatus == ChannelStatus::WAIT)
-		blink();
+		mainButton->blink(g_ui->shouldBlink());
 
 	playButton->setValue(playStatus == ChannelStatus::PLAY || playStatus == ChannelStatus::ENDING);
 	midiActivity->redraw();
@@ -114,16 +110,6 @@ bool geChannel::isGroup() const
 
 /* -------------------------------------------------------------------------- */
 
-void geChannel::blink()
-{
-	if (g_ui->shouldBlink())
-		mainButton->setPlayMode();
-	else
-		mainButton->setDefaultMode();
-}
-
-/* -------------------------------------------------------------------------- */
-
 bool geChannel::handleKey(int e)
 {
 	if (Fl::event_key() != m_channel.key)
