@@ -25,11 +25,11 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/gui/elems/mainWindow/keyboard/channelProgress.h"
+#include "src/deps/mcl-utils/src/math.hpp"
 #include "src/glue/channel.h"
 #include "src/gui/const.h"
 #include "src/gui/drawing.h"
 #include "src/gui/types.h"
-#include "src/utils/math.h"
 
 namespace giada::v
 {
@@ -43,18 +43,17 @@ geChannelProgress::geChannelProgress(int x, int y, int w, int h, c::channel::Dat
 
 void geChannelProgress::draw()
 {
-	const ChannelStatus playStatus = m_channel.getPlayStatus();
-	const Frame         tracker    = m_channel.sample->getTracker();
-	const auto          range      = m_channel.sample->range;
-	const Pixel         pos        = u::math::map(std::max(tracker, range.a), range.a, range.b, 0, w());
+	namespace math = mcl::utils::math;
+
+	const Frame tracker = m_channel.sample->getTracker();
+	const auto  range   = m_channel.sample->range;
+	const Pixel pos     = range.isValid() ? math::map(std::max(tracker, range.a), range.a, range.b, 0, w()) : 0;
 
 	const geompp::Rect<int> bounds(x(), y(), w(), h());
 
 	drawRectf(bounds, G_COLOR_GREY_2); // reset background
 
-	if (playStatus == ChannelStatus::PLAY ||
-	    playStatus == ChannelStatus::WAIT ||
-	    playStatus == ChannelStatus::ENDING)
+	if (m_channel.isActive())
 	{
 		drawRectf(bounds.withW(pos), G_COLOR_LIGHT_1);
 		drawRect(bounds, G_COLOR_LIGHT_1);
