@@ -25,6 +25,8 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/gui/elems/mainWindow/keyboard/keyboard.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
+#include "src/deps/mcl-utils/src/string.hpp"
 #include "src/glue/channel.h"
 #include "src/glue/io.h"
 #include "src/gui/const.h"
@@ -38,14 +40,14 @@
 #include "src/gui/elems/mainWindow/keyboard/track.h"
 #include "src/gui/elems/midiActivity.h"
 #include "src/gui/ui.h"
-#include "src/utils/fs.h"
 #include "src/utils/gui.h"
 #include "src/utils/log.h"
-#include "src/utils/string.h"
 #include <cassert>
 
 extern giada::v::Ui* g_ui;
 
+namespace utils = mcl::utils;
+
 namespace giada::v
 {
 namespace
@@ -477,9 +479,9 @@ geChannel* geKeyboard::getChannel(ID channelId)
 
 std::vector<std::string> geKeyboard::getDroppedFilePaths() const
 {
-	std::vector<std::string> paths = u::string::split(Fl::event_text(), "\n");
+	std::vector<std::string> paths = utils::string::split(Fl::event_text(), "\n");
 	for (std::string& p : paths)
-		p = u::fs::stripFileUrl(p);
+		p = utils::fs::uriToPath(p);
 	return paths;
 }
 
