@@ -28,22 +28,14 @@
 #include "src/glue/channel.h"
 #include "src/glue/io.h"
 #include "src/glue/layout.h"
-#include "src/glue/main.h"
-#include "src/gui/dialogs/warnings.h"
-#include "src/gui/dispatcher.h"
-#include "src/gui/elems/basics/boxtypes.h"
 #include "src/gui/elems/basics/dial.h"
 #include "src/gui/elems/basics/imageButton.h"
 #include "src/gui/elems/basics/menu.h"
 #include "src/gui/elems/mainWindow/keyboard/midiChannelButton.h"
-#include "src/gui/elems/mainWindow/keyboard/track.h"
 #include "src/gui/elems/midiActivity.h"
 #include "src/gui/graphics.h"
 #include "src/gui/ui.h"
-#include "src/utils/gui.h"
-#include "src/utils/string.h"
-#include <FL/Fl_Menu_Button.H>
-#include <cassert>
+#include <fmt/core.h>
 
 extern giada::v::Ui* g_ui;
 
@@ -54,13 +46,22 @@ namespace
 enum class Menu
 {
 	EDIT_ACTIONS = 0,
-	CLEAR_ACTIONS,
+	CLEAR_ACTIONS_THIS_SCENE,
+	CLEAR_ACTIONS_ALL_SCENES,
 	SETUP_KEYBOARD_INPUT,
 	SETUP_MIDI_INPUT,
 	SETUP_MIDI_OUTPUT,
 	EDIT_ROUTING,
 	RENAME_CHANNEL,
 	CLONE_CHANNEL,
+	COPY_CHANNEL_TO_SCENE_0,
+	COPY_CHANNEL_TO_SCENE_1,
+	COPY_CHANNEL_TO_SCENE_2,
+	COPY_CHANNEL_TO_SCENE_3,
+	COPY_CHANNEL_TO_SCENE_4,
+	COPY_CHANNEL_TO_SCENE_5,
+	COPY_CHANNEL_TO_SCENE_6,
+	COPY_CHANNEL_TO_SCENE_7,
 	DELETE_CHANNEL
 };
 } // namespace
@@ -72,7 +73,7 @@ geMidiChannel::geMidiChannel(int X, int Y, int W, int H, c::channel::Data d)
 {
 	playButton   = new geImageButton(graphics::channelPlayOff, graphics::channelPlayOn);
 	arm          = new geImageButton(graphics::armOff, graphics::armOn);
-	mainButton   = new geMidiChannelButton(0, 0, 0, 0, m_channel);
+	mainButton   = new geMidiChannelButton(m_channel);
 	midiActivity = new geMidiActivity();
 	mute         = new geImageButton(graphics::muteOff, graphics::muteOn);
 	solo         = new geImageButton(graphics::soloOff, graphics::soloOn);
@@ -143,17 +144,37 @@ void geMidiChannel::openMenu()
 	geMenu menu;
 
 	menu.addItem((ID)Menu::EDIT_ACTIONS, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_EDITACTIONS));
-	menu.addItem((ID)Menu::CLEAR_ACTIONS, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS));
+
+	geMenu clearActionsSubMenu;
+	clearActionsSubMenu.addItem((ID)Menu::CLEAR_ACTIONS_THIS_SCENE, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS_THISSCENE));
+	clearActionsSubMenu.addItem((ID)Menu::CLEAR_ACTIONS_ALL_SCENES, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS_ALLSCENES));
+	menu.addSubMenu(g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS), clearActionsSubMenu);
+
 	menu.addItem((ID)Menu::SETUP_KEYBOARD_INPUT, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_KEYBOARDINPUT));
 	menu.addItem((ID)Menu::SETUP_MIDI_INPUT, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_MIDIINPUT));
 	menu.addItem((ID)Menu::SETUP_MIDI_OUTPUT, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_MIDIOUTPUT));
 	menu.addItem((ID)Menu::EDIT_ROUTING, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_EDITROUTING));
 	menu.addItem((ID)Menu::RENAME_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_RENAME));
 	menu.addItem((ID)Menu::CLONE_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLONE));
+
+	geMenu copySceneSubMenu;
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_0, fmt::format("{} 1", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_1, fmt::format("{} 2", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_2, fmt::format("{} 3", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_3, fmt::format("{} 4", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_4, fmt::format("{} 5", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_5, fmt::format("{} 6", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_6, fmt::format("{} 7", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_7, fmt::format("{} 8", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	menu.addSubMenu(g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_COPYTOSCENE), copySceneSubMenu);
+
 	menu.addItem((ID)Menu::DELETE_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_DELETE));
 
 	if (!m_channel.hasActions)
-		menu.setEnabled((ID)Menu::CLEAR_ACTIONS, false);
+	{
+		menu.setEnabled((ID)Menu::CLEAR_ACTIONS_THIS_SCENE, false);
+		menu.setEnabled((ID)Menu::CLEAR_ACTIONS_ALL_SCENES, false);
+	}
 
 	menu.onSelect = [&data = m_channel](ID id)
 	{
@@ -162,8 +183,11 @@ void geMidiChannel::openMenu()
 		case Menu::EDIT_ACTIONS:
 			c::layout::openMidiActionEditor(data.id);
 			break;
-		case Menu::CLEAR_ACTIONS:
-			c::channel::clearAllActions(data.id);
+		case Menu::CLEAR_ACTIONS_THIS_SCENE:
+			c::channel::clearAllActions(data.id, /*allScenes=*/false);
+			break;
+		case Menu::CLEAR_ACTIONS_ALL_SCENES:
+			c::channel::clearAllActions(data.id, /*allScenes=*/true);
 			break;
 		case Menu::SETUP_KEYBOARD_INPUT:
 			c::layout::openKeyGrabberWindow(data.key, [channelId = data.id](int key)
@@ -183,6 +207,30 @@ void geMidiChannel::openMenu()
 		case Menu::CLONE_CHANNEL:
 			c::channel::cloneChannel(data.id);
 			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_0:
+			c::channel::copyChannelToScene(data.id, 0);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_1:
+			c::channel::copyChannelToScene(data.id, 1);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_2:
+			c::channel::copyChannelToScene(data.id, 2);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_3:
+			c::channel::copyChannelToScene(data.id, 3);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_4:
+			c::channel::copyChannelToScene(data.id, 4);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_5:
+			c::channel::copyChannelToScene(data.id, 5);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_6:
+			c::channel::copyChannelToScene(data.id, 6);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_7:
+			c::channel::copyChannelToScene(data.id, 7);
+			break;
 		case Menu::RENAME_CHANNEL:
 			c::layout::openRenameChannelWindow(data);
 			break;
