@@ -28,19 +28,16 @@
 #include "src/glue/channel.h"
 #include "src/glue/io.h"
 #include "src/glue/layout.h"
-#include "src/glue/main.h"
-#include "src/gui/dispatcher.h"
 #include "src/gui/elems/basics/dial.h"
 #include "src/gui/elems/basics/imageButton.h"
 #include "src/gui/elems/basics/menu.h"
 #include "src/gui/elems/mainWindow/keyboard/channelProgress.h"
-#include "src/gui/elems/mainWindow/keyboard/keyboard.h"
 #include "src/gui/elems/mainWindow/keyboard/sampleChannelButton.h"
 #include "src/gui/elems/mainWindow/keyboard/sampleChannelMode.h"
-#include "src/gui/elems/mainWindow/keyboard/track.h"
 #include "src/gui/elems/midiActivity.h"
 #include "src/gui/graphics.h"
 #include "src/gui/ui.h"
+#include <fmt/core.h>
 
 extern giada::v::Ui* g_ui;
 
@@ -60,10 +57,20 @@ enum class Menu
 	EDIT_ROUTING,
 	EDIT_SAMPLE,
 	EDIT_ACTIONS,
-	CLEAR_ACTIONS,
+	CLEAR_ACTIONS_THIS_SCENE,
+	CLEAR_ACTIONS_ALL_SCENES,
 	RENAME_CHANNEL,
 	CLONE_CHANNEL,
-	FREE_CHANNEL,
+	COPY_CHANNEL_TO_SCENE_0,
+	COPY_CHANNEL_TO_SCENE_1,
+	COPY_CHANNEL_TO_SCENE_2,
+	COPY_CHANNEL_TO_SCENE_3,
+	COPY_CHANNEL_TO_SCENE_4,
+	COPY_CHANNEL_TO_SCENE_5,
+	COPY_CHANNEL_TO_SCENE_6,
+	COPY_CHANNEL_TO_SCENE_7,
+	FREE_CHANNEL_THIS_SCENE,
+	FREE_CHANNEL_ALL_SCENES,
 	DELETE_CHANNEL
 };
 } // namespace
@@ -78,7 +85,7 @@ geSampleChannel::geSampleChannel(int X, int Y, int W, int H, c::channel::Data d)
 	playButton     = new geImageButton(graphics::channelPlayOff, graphics::channelPlayOn);
 	arm            = new geImageButton(graphics::armOff, graphics::armOn, graphics::armDisabled);
 	progress       = new geChannelProgress(0, 0, 0, 0, m_channel);
-	mainButton     = new geSampleChannelButton(0, 0, 0, 0, m_channel);
+	mainButton     = new geSampleChannelButton(m_channel);
 	midiActivity   = new geMidiActivity();
 	readActionsBtn = new geImageButton(graphics::readActionOff, graphics::readActionOn, graphics::readActionDisabled);
 	modeBox        = new geSampleChannelMode(0, 0, 0, 0, m_channel);
@@ -178,22 +185,47 @@ void geSampleChannel::openMenu()
 	menu.addItem((ID)Menu::EDIT_ROUTING, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_EDITROUTING));
 	menu.addItem((ID)Menu::EDIT_SAMPLE, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_EDITSAMPLE));
 	menu.addItem((ID)Menu::EDIT_ACTIONS, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_EDITACTIONS));
-	menu.addItem((ID)Menu::CLEAR_ACTIONS, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS));
+
+	geMenu clearActionsSubMenu;
+	clearActionsSubMenu.addItem((ID)Menu::CLEAR_ACTIONS_THIS_SCENE, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS_THISSCENE));
+	clearActionsSubMenu.addItem((ID)Menu::CLEAR_ACTIONS_ALL_SCENES, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS_ALLSCENES));
+	menu.addSubMenu(g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLEARACTIONS), clearActionsSubMenu);
+
 	menu.addItem((ID)Menu::RENAME_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_RENAME));
 	menu.addItem((ID)Menu::CLONE_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_CLONE));
-	menu.addItem((ID)Menu::FREE_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_FREE));
+
+	geMenu copySceneSubMenu;
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_0, fmt::format("{} 1", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_1, fmt::format("{} 2", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_2, fmt::format("{} 3", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_3, fmt::format("{} 4", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_4, fmt::format("{} 5", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_5, fmt::format("{} 6", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_6, fmt::format("{} 7", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	copySceneSubMenu.addItem((ID)Menu::COPY_CHANNEL_TO_SCENE_7, fmt::format("{} 8", g_ui->getI18Text(LangMap::COMMON_SCENE)));
+	menu.addSubMenu(g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_COPYTOSCENE), copySceneSubMenu);
+
+	geMenu freeChannelSubMenu;
+	freeChannelSubMenu.addItem((ID)Menu::FREE_CHANNEL_THIS_SCENE, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_FREETHISSCENE));
+	freeChannelSubMenu.addItem((ID)Menu::FREE_CHANNEL_ALL_SCENES, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_FREEALLSCENES));
+	menu.addSubMenu(g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_FREE), freeChannelSubMenu);
+
 	menu.addItem((ID)Menu::DELETE_CHANNEL, g_ui->getI18Text(LangMap::MAIN_CHANNEL_MENU_DELETE));
 
 	if (m_channel.sample->waveId == 0)
 	{
 		menu.setEnabled((ID)Menu::EXPORT_SAMPLE, false);
 		menu.setEnabled((ID)Menu::EDIT_SAMPLE, false);
-		menu.setEnabled((ID)Menu::FREE_CHANNEL, false);
 		menu.setEnabled((ID)Menu::RENAME_CHANNEL, false);
+		menu.setEnabled((ID)Menu::FREE_CHANNEL_THIS_SCENE, false);
+		menu.setEnabled((ID)Menu::FREE_CHANNEL_ALL_SCENES, false);
 	}
 
 	if (!m_channel.hasActions)
-		menu.setEnabled((ID)Menu::CLEAR_ACTIONS, false);
+	{
+		menu.setEnabled((ID)Menu::CLEAR_ACTIONS_ALL_SCENES, false);
+		menu.setEnabled((ID)Menu::CLEAR_ACTIONS_THIS_SCENE, false);
+	}
 
 	menu.onSelect = [&channel = m_channel](ID id)
 	{
@@ -242,20 +274,51 @@ void geSampleChannel::openMenu()
 			c::layout::openSampleActionEditor(channel.id);
 			break;
 
-		case Menu::CLEAR_ACTIONS:
-			c::channel::clearAllActions(channel.id);
+		case Menu::CLEAR_ACTIONS_THIS_SCENE:
+			c::channel::clearAllActions(channel.id, /*allScenes=*/false);
+			break;
+		case Menu::CLEAR_ACTIONS_ALL_SCENES:
+			c::channel::clearAllActions(channel.id, /*allScenes=*/true);
 			break;
 
 		case Menu::CLONE_CHANNEL:
 			c::channel::cloneChannel(channel.id);
 			break;
 
+		case Menu::COPY_CHANNEL_TO_SCENE_0:
+			c::channel::copyChannelToScene(channel.id, 0);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_1:
+			c::channel::copyChannelToScene(channel.id, 1);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_2:
+			c::channel::copyChannelToScene(channel.id, 2);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_3:
+			c::channel::copyChannelToScene(channel.id, 3);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_4:
+			c::channel::copyChannelToScene(channel.id, 4);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_5:
+			c::channel::copyChannelToScene(channel.id, 5);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_6:
+			c::channel::copyChannelToScene(channel.id, 6);
+			break;
+		case Menu::COPY_CHANNEL_TO_SCENE_7:
+			c::channel::copyChannelToScene(channel.id, 7);
+			break;
+
 		case Menu::RENAME_CHANNEL:
 			c::layout::openRenameChannelWindow(channel);
 			break;
 
-		case Menu::FREE_CHANNEL:
-			c::channel::freeChannel(channel.id);
+		case Menu::FREE_CHANNEL_THIS_SCENE:
+			c::channel::freeChannel(channel.id, /*allScenes=*/false);
+			break;
+		case Menu::FREE_CHANNEL_ALL_SCENES:
+			c::channel::freeChannel(channel.id, /*allScenes=*/true);
 			break;
 
 		case Menu::DELETE_CHANNEL:
