@@ -25,21 +25,23 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/gui/elems/mainWindow/keyboard/sampleChannelButton.h"
+#include "src/deps/mcl-utils/src/fs.hpp"
+#include "src/deps/mcl-utils/src/string.hpp"
 #include "src/glue/channel.h"
 #include "src/gui/dialogs/mainWindow.h"
 #include "src/gui/elems/mainWindow/keyboard/keyboard.h"
 #include "src/gui/elems/mainWindow/keyboard/sampleChannel.h"
 #include "src/gui/ui.h"
-#include "src/utils/fs.h"
-#include "src/utils/string.h"
 #include <FL/Fl.H>
 
 extern giada::v::Ui* g_ui;
 
+namespace utils = mcl::utils;
+
 namespace giada::v
 {
-geSampleChannelButton::geSampleChannelButton(int x, int y, int w, int h, const c::channel::Data& d)
-: geChannelButton(x, y, w, h, d)
+geSampleChannelButton::geSampleChannelButton(const c::channel::Data& d)
+: geChannelButton(d)
 {
 	switch (m_channel.getPlayStatus())
 	{
@@ -60,9 +62,9 @@ void geSampleChannelButton::refresh()
 	geChannelButton::refresh();
 
 	if (m_channel.isRecordingInput() && m_channel.isArmed())
-		setInputRecordMode();
+		setInputRecordState();
 	else if (m_channel.isRecordingActions() && m_channel.sample->waveId != 0 && !m_channel.sample->isLoop)
-		setActionRecordMode();
+		setActionRecordState();
 
 	redraw();
 }
@@ -83,7 +85,7 @@ int geSampleChannelButton::handle(int e)
 	}
 	case FL_PASTE:
 	{
-		c::channel::loadChannel(m_channel.id, u::string::trim(u::fs::stripFileUrl(Fl::event_text())));
+		c::channel::loadChannel(m_channel.id, utils::string::trim(utils::fs::uriToPath(Fl::event_text())));
 		ret = 1;
 		break;
 	}
