@@ -25,6 +25,7 @@
  * -------------------------------------------------------------------------- */
 
 #include "src/gui/elems/sampleEditor/rangeTool.h"
+#include "src/deps/mcl-utils/src/string.hpp"
 #include "src/glue/channel.h"
 #include "src/glue/sampleEditor.h"
 #include "src/gui/dialogs/sampleEditor.h"
@@ -33,10 +34,11 @@
 #include "src/gui/elems/basics/pack.h"
 #include "src/gui/elems/basics/textButton.h"
 #include "src/gui/ui.h"
-#include "src/utils/string.h"
 
 extern giada::v::Ui* g_ui;
 
+namespace utils = mcl::utils;
+
 namespace giada::v
 {
 geRangeTool::geRangeTool(const c::sampleEditor::Data& d)
@@ -57,14 +59,14 @@ geRangeTool::geRangeTool(const c::sampleEditor::Data& d)
 	m_begin->setWhen(FL_WHEN_RELEASE | FL_WHEN_ENTER_KEY); // on focus lost or enter key
 	m_begin->onChange = [this](const std::string& val)
 	{
-		c::sampleEditor::setRange(m_data->channelId, {u::string::toInt(val), u::string::toInt(m_end->getValue())});
+		c::sampleEditor::setRange(m_data->channelId, {utils::string::toInt(val), utils::string::toInt(m_end->getValue())});
 	};
 
 	m_end->setType(FL_INT_INPUT);
 	m_end->setWhen(FL_WHEN_RELEASE | FL_WHEN_ENTER_KEY); // on focus lost or enter key
 	m_end->onChange = [this](const std::string& val)
 	{
-		c::sampleEditor::setRange(m_data->channelId, {u::string::toInt(m_begin->getValue()), u::string::toInt(val)});
+		c::sampleEditor::setRange(m_data->channelId, {utils::string::toInt(m_begin->getValue()), utils::string::toInt(val)});
 	};
 
 	m_reset->onClick = [this]()
@@ -80,7 +82,7 @@ geRangeTool::geRangeTool(const c::sampleEditor::Data& d)
 void geRangeTool::rebuild(const c::sampleEditor::Data& d)
 {
 	m_data = &d;
-	update(m_data->range);
+	update(m_data->sample.range);
 }
 
 /* -------------------------------------------------------------------------- */
