@@ -60,6 +60,7 @@ LangMap::LangMap()
 	m_data[COMMON_NOTSET]     = "(not set)";
 	m_data[COMMON_NONE]       = "None";
 	m_data[COMMON_APPLY]      = "Apply";
+	m_data[COMMON_SCENE]      = "Scene";
 
 	m_data[MESSAGE_MAIN_FREEALLSAMPLES]           = "Free all Sample channels: are you sure?";
 	m_data[MESSAGE_MAIN_CLEARALLACTIONS]          = "Clear all actions: are you sure?";
@@ -170,12 +171,17 @@ LangMap::LangMap()
 	m_data[MAIN_CHANNEL_MENU_EDITSAMPLE]             = "Edit sample...";
 	m_data[MAIN_CHANNEL_MENU_EDITACTIONS]            = "Edit actions...";
 	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS]           = "Clear actions";
+	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS_THISSCENE] = "In this scene";
+	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS_ALLSCENES] = "In all scenes";
 	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS_ALL]       = "All";
 	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS_VOLUME]    = "Volume";
 	m_data[MAIN_CHANNEL_MENU_CLEARACTIONS_STARTSTOP] = "Start/Stop";
 	m_data[MAIN_CHANNEL_MENU_RENAME]                 = "Rename";
 	m_data[MAIN_CHANNEL_MENU_CLONE]                  = "Clone";
-	m_data[MAIN_CHANNEL_MENU_FREE]                   = "Free";
+	m_data[MAIN_CHANNEL_MENU_COPYTOSCENE]            = "Copy to scene";
+	m_data[MAIN_CHANNEL_MENU_FREE]                   = "Free sample";
+	m_data[MAIN_CHANNEL_MENU_FREETHISSCENE]          = "For this scene";
+	m_data[MAIN_CHANNEL_MENU_FREEALLSCENES]          = "For all scenes";
 	m_data[MAIN_CHANNEL_MENU_DELETE]                 = "Delete";
 
 	m_data[MISSINGASSETS_INTRO]      = "This project contains missing assets.";
@@ -222,7 +228,7 @@ LangMap::LangMap()
 	m_data[SAMPLEEDITOR_TOOLS_FADE_IN]        = "Fade in";
 	m_data[SAMPLEEDITOR_TOOLS_FADE_OUT]       = "Fade out";
 	m_data[SAMPLEEDITOR_TOOLS_SMOOTH_EDGES]   = "Smooth edges";
-	m_data[SAMPLEEDITOR_TOOLS_SET_RANGE]      = "Set begin/end here";
+	m_data[SAMPLEEDITOR_TOOLS_SET_RANGE]      = "Set range here";
 	m_data[SAMPLEEDITOR_TOOLS_TO_NEW_CHANNEL] = "Copy to new channel";
 
 	m_data[ACTIONEDITOR_TITLE]            = "Action Editor";
