@@ -1,5 +1,5 @@
 #include "../src/version.h"
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 TEST_CASE("Version")
 {
